# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import ListIPsRequestOrderBy
from .types import ResourceType
from .types import Resource
from .types import Reverse
from .types import Source
from .types import IP
from .types import BookIPRequest
from .types import GetIPRequest
from .types import ListIPsRequest
from .types import ListIPsResponse
from .types import ReleaseIPRequest
from .types import ReleaseIPSetRequest
from .types import UpdateIPRequest
from .api import IpamV1API

__all__ = [
    "ListIPsRequestOrderBy",
    "ResourceType",
    "Resource",
    "Reverse",
    "Source",
    "IP",
    "BookIPRequest",
    "GetIPRequest",
    "ListIPsRequest",
    "ListIPsResponse",
    "ReleaseIPRequest",
    "ReleaseIPSetRequest",
    "UpdateIPRequest",
    "IpamV1API",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.

from datetime import datetime
from typing import List, Optional

from scaleway_core.api import API
from scaleway_core.bridge import (
    Region,
)
from scaleway_core.utils import (
    WaitForOptions,
    validate_path_param,
    fetch_all_pages,
    wait_for_resource,
)
from .types import (
    DomainStatus,
    EmailFlag,
    EmailStatus,
    ListEmailsRequestOrderBy,
    ListWebhookEventsRequestOrderBy,
    ListWebhooksRequestOrderBy,
    WebhookEventStatus,
    WebhookEventType,
    CreateDomainRequest,
    CreateEmailRequest,
    CreateEmailRequestAddress,
    CreateEmailRequestAttachment,
    CreateEmailRequestHeader,
    CreateEmailResponse,
    CreateWebhookRequest,
    Domain,
    DomainLastStatus,
    Email,
    ListDomainsResponse,
    ListEmailsResponse,
    ListWebhookEventsResponse,
    ListWebhooksResponse,
    Statistics,
    UpdateWebhookRequest,
    Webhook,
    WebhookEvent,
)
from .content import (
    DOMAIN_TRANSIENT_STATUSES,
    EMAIL_TRANSIENT_STATUSES,
)
from .marshalling import (
    unmarshal_Email,
    unmarshal_Domain,
    unmarshal_Webhook,
    unmarshal_CreateEmailResponse,
    unmarshal_DomainLastStatus,
    unmarshal_ListDomainsResponse,
    unmarshal_ListEmailsResponse,
    unmarshal_ListWebhookEventsResponse,
    unmarshal_ListWebhooksResponse,
    unmarshal_Statistics,
    marshal_CreateDomainRequest,
    marshal_CreateEmailRequest,
    marshal_CreateWebhookRequest,
    marshal_UpdateWebhookRequest,
)


class TemV1Alpha1API(API):
    """
    This API allows you to manage your Transactional Email services.
    """

    def create_email(
        self,
        *,
        from_: CreateEmailRequestAddress,
        subject: str,
        text: str,
        html: str,
        region: Optional[Region] = None,
        to: Optional[List[CreateEmailRequestAddress]] = None,
        cc: Optional[List[CreateEmailRequestAddress]] = None,
        bcc: Optional[List[CreateEmailRequestAddress]] = None,
        project_id: Optional[str] = None,
        attachments: Optional[List[CreateEmailRequestAttachment]] = None,
        send_before: Optional[datetime] = None,
        additional_headers: Optional[List[CreateEmailRequestHeader]] = None,
    ) -> CreateEmailResponse:
        """
        Send an email.
        You must specify the `region`, the sender and the recipient's information and the `project_id` to send an email from a checked domain. The subject of the email must contain at least 6 characters.
        :param from_: Sender information. Must be from a checked domain declared in the Project.
        :param subject: Subject of the email.
        :param text: Text content.
        :param html: HTML content.
        :param region: Region to target. If none is passed will use default region from the config.
        :param to: An array of the primary recipient's information.
        :param cc: An array of the carbon copy recipient's information.
        :param bcc: An array of the blind carbon copy recipient's information.
        :param project_id: ID of the Project in which to create the email.
        :param attachments: Array of attachments.
        :param send_before: Maximum date to deliver the email.
        :param additional_headers: Array of additional headers as key-value.
        :return: :class:`CreateEmailResponse <CreateEmailResponse>`

        Usage:
        ::

            result = api.create_email(
                from=CreateEmailRequestAddress(),
                subject="example",
                text="example",
                html="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/transactional-email/v1alpha1/regions/{param_region}/emails",
            body=marshal_CreateEmailRequest(
                CreateEmailRequest(
                    from_=from_,
                    subject=subject,
                    text=text,
                    html=html,
                    region=region,
                    to=to,
                    cc=cc,
                    bcc=bcc,
                    project_id=project_id,
                    attachments=attachments,
                    send_before=send_before,
                    additional_headers=additional_headers,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_CreateEmailResponse(res.json())

    def get_email(
        self,
        *,
        email_id: str,
        region: Optional[Region] = None,
    ) -> Email:
        """
        Get an email.
        Retrieve information about a specific email using the `email_id` and `region` parameters.
        :param email_id: ID of the email to retrieve.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`Email <Email>`

        Usage:
        ::

            result = api.get_email(
                email_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_email_id = validate_path_param("email_id", email_id)

        res = self._request(
            "GET",
            f"/transactional-email/v1alpha1/regions/{param_region}/emails/{param_email_id}",
        )

        self._throw_on_error(res)
        return unmarshal_Email(res.json())

    def wait_for_email(
        self,
        *,
        email_id: str,
        region: Optional[Region] = None,
        options: Optional[WaitForOptions[Email, bool]] = None,
    ) -> Email:
        """
        Get an email.
        Retrieve information about a specific email using the `email_id` and `region` parameters.
        :param email_id: ID of the email to retrieve.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`Email <Email>`

        Usage:
        ::

            result = api.get_email(
                email_id="example",
            )
        """

        if not options:
            options = WaitForOptions()

        if not options.stop:
            options.stop = lambda res: res.status not in EMAIL_TRANSIENT_STATUSES

        return wait_for_resource(
            fetcher=self.get_email,
            options=options,
            args={
                "email_id": email_id,
                "region": region,
            },
        )

    def list_emails(
        self,
        *,
        region: Optional[Region] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        project_id: Optional[str] = None,
        domain_id: Optional[str] = None,
        message_id: Optional[str] = None,
        since: Optional[datetime] = None,
        until: Optional[datetime] = None,
        mail_from: Optional[str] = None,
        mail_to: Optional[str] = None,
        mail_rcpt: Optional[str] = None,
        statuses: Optional[List[EmailStatus]] = None,
        subject: Optional[str] = None,
        search: Optional[str] = None,
        order_by: Optional[ListEmailsRequestOrderBy] = None,
        flags: Optional[List[EmailFlag]] = None,
    ) -> ListEmailsResponse:
        """
        List emails.
        Retrieve the list of emails sent from a specific domain or for a specific Project or Organization. You must specify the `region`.
        :param region: Region to target. If none is passed will use default region from the config.
        :param page:
        :param page_size:
        :param project_id: (Optional) ID of the Project in which to list the emails.
        :param domain_id: (Optional) ID of the domain for which to list the emails.
        :param message_id: (Optional) ID of the message for which to list the emails.
        :param since: (Optional) List emails created after this date.
        :param until: (Optional) List emails created before this date.
        :param mail_from: (Optional) List emails sent with this sender's email address.
        :param mail_to: List emails sent to this recipient's email address.
        :param mail_rcpt: (Optional) List emails sent to this recipient's email address.
        :param statuses: (Optional) List emails with any of these statuses.
        :param subject: (Optional) List emails with this subject.
        :param search: (Optional) List emails by searching to all fields.
        :param order_by: (Optional) List emails corresponding to specific criteria.
        :param flags: (Optional) List emails containing only specific flags.
        :return: :class:`ListEmailsResponse <ListEmailsResponse>`

        Usage:
        ::

            result = api.list_emails()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "GET",
            f"/transactional-email/v1alpha1/regions/{param_region}/emails",
            params={
                "domain_id": domain_id,
                "flags": flags,
                "mail_from": mail_from,
                "mail_rcpt": mail_rcpt,
                "mail_to": mail_to,
                "message_id": message_id,
                "order_by": order_by,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
                "search": search,
                "since": since,
                "statuses": statuses,
                "subject": subject,
                "until": until,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListEmailsResponse(res.json())

    def list_emails_all(
        self,
        *,
        region: Optional[Region] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        project_id: Optional[str] = None,
        domain_id: Optional[str] = None,
        message_id: Optional[str] = None,
        since: Optional[datetime] = None,
        until: Optional[datetime] = None,
        mail_from: Optional[str] = None,
        mail_to: Optional[str] = None,
        mail_rcpt: Optional[str] = None,
        statuses: Optional[List[EmailStatus]] = None,
        subject: Optional[str] = None,
        search: Optional[str] = None,
        order_by: Optional[ListEmailsRequestOrderBy] = None,
        flags: Optional[List[EmailFlag]] = None,
    ) -> List[Email]:
        """
        List emails.
        Retrieve the list of emails sent from a specific domain or for a specific Project or Organization. You must specify the `region`.
        :param region: Region to target. If none is passed will use default region from the config.
        :param page:
        :param page_size:
        :param project_id: (Optional) ID of the Project in which to list the emails.
        :param domain_id: (Optional) ID of the domain for which to list the emails.
        :param message_id: (Optional) ID of the message for which to list the emails.
        :param since: (Optional) List emails created after this date.
        :param until: (Optional) List emails created before this date.
        :param mail_from: (Optional) List emails sent with this sender's email address.
        :param mail_to: List emails sent to this recipient's email address.
        :param mail_rcpt: (Optional) List emails sent to this recipient's email address.
        :param statuses: (Optional) List emails with any of these statuses.
        :param subject: (Optional) List emails with this subject.
        :param search: (Optional) List emails by searching to all fields.
        :param order_by: (Optional) List emails corresponding to specific criteria.
        :param flags: (Optional) List emails containing only specific flags.
        :return: :class:`List[Email] <List[Email]>`

        Usage:
        ::

            result = api.list_emails_all()
        """

        return fetch_all_pages(
            type=ListEmailsResponse,
            key="emails",
            fetcher=self.list_emails,
            args={
                "region": region,
                "page": page,
                "page_size": page_size,
                "project_id": project_id,
                "domain_id": domain_id,
                "message_id": message_id,
                "since": since,
                "until": until,
                "mail_from": mail_from,
                "mail_to": mail_to,
                "mail_rcpt": mail_rcpt,
                "statuses": statuses,
                "subject": subject,
                "search": search,
                "order_by": order_by,
                "flags": flags,
            },
        )

    def get_statistics(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        domain_id: Optional[str] = None,
        since: Optional[datetime] = None,
        until: Optional[datetime] = None,
        mail_from: Optional[str] = None,
    ) -> Statistics:
        """
        Email statuses.
        Get information on your emails' statuses.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: (Optional) Number of emails for this Project.
        :param domain_id: (Optional) Number of emails sent from this domain (must be coherent with the `project_id` and the `organization_id`).
        :param since: (Optional) Number of emails created after this date.
        :param until: (Optional) Number of emails created before this date.
        :param mail_from: (Optional) Number of emails sent with this sender's email address.
        :return: :class:`Statistics <Statistics>`

        Usage:
        ::

            result = api.get_statistics()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "GET",
            f"/transactional-email/v1alpha1/regions/{param_region}/statistics",
            params={
                "domain_id": domain_id,
                "mail_from": mail_from,
                "project_id": project_id or self.client.default_project_id,
                "since": since,
                "until": until,
            },
        )

        self._throw_on_error(res)
        return unmarshal_Statistics(res.json())

    def cancel_email(
        self,
        *,
        email_id: str,
        region: Optional[Region] = None,
    ) -> Email:
        """
        Cancel an email.
        You can cancel the sending of an email if it has not been sent yet. You must specify the `region` and the `email_id` of the email you want to cancel.
        :param email_id: ID of the email to cancel.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`Email <Email>`

        Usage:
        ::

            result = api.cancel_email(
                email_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_email_id = validate_path_param("email_id", email_id)

        res = self._request(
            "POST",
            f"/transactional-email/v1alpha1/regions/{param_region}/emails/{param_email_id}/cancel",
            body={},
        )

        self._throw_on_error(res)
        return unmarshal_Email(res.json())

    def create_domain(
        self,
        *,
        domain_name: str,
        accept_tos: bool,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
    ) -> Domain:
        """
        Register a domain in a project.
        You must specify the `region`, `project_id` and `domain_name` to register a domain in a specific Project.
        :param domain_name: Fully qualified domain dame.
        :param accept_tos: Accept Scaleway's Terms of Service.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: ID of the project to which the domain belongs.
        :return: :class:`Domain <Domain>`

        Usage:
        ::

            result = api.create_domain(
                domain_name="example",
                accept_tos=False,
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/transactional-email/v1alpha1/regions/{param_region}/domains",
            body=marshal_CreateDomainRequest(
                CreateDomainRequest(
                    domain_name=domain_name,
                    accept_tos=accept_tos,
                    region=region,
                    project_id=project_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Domain(res.json())

    def get_domain(
        self,
        *,
        domain_id: str,
        region: Optional[Region] = None,
    ) -> Domain:
        """
        Get information about a domain.
        Retrieve information about a specific domain using the `region` and `domain_id` parameters. Monitor your domain's reputation and improve **average** and **bad** reputation statuses, using your domain's **Email activity** tab on the [Scaleway console](https://console.scaleway.com/transactional-email/domains) to get a more detailed report. Check out our [dedicated documentation](https://www.scaleway.com/en/docs/managed-services/transactional-email/reference-content/understanding-tem-reputation-score/) to improve your domain's reputation.
        :param domain_id: ID of the domain.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`Domain <Domain>`

        Usage:
        ::

            result = api.get_domain(
                domain_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_domain_id = validate_path_param("domain_id", domain_id)

        res = self._request(
            "GET",
            f"/transactional-email/v1alpha1/regions/{param_region}/domains/{param_domain_id}",
        )

        self._throw_on_error(res)
        return unmarshal_Domain(res.json())

    def wait_for_domain(
        self,
        *,
        domain_id: str,
        region: Optional[Region] = None,
        options: Optional[WaitForOptions[Domain, bool]] = None,
    ) -> Domain:
        """
        Get information about a domain.
        Retrieve information about a specific domain using the `region` and `domain_id` parameters. Monitor your domain's reputation and improve **average** and **bad** reputation statuses, using your domain's **Email activity** tab on the [Scaleway console](https://console.scaleway.com/transactional-email/domains) to get a more detailed report. Check out our [dedicated documentation](https://www.scaleway.com/en/docs/managed-services/transactional-email/reference-content/understanding-tem-reputation-score/) to improve your domain's reputation.
        :param domain_id: ID of the domain.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`Domain <Domain>`

        Usage:
        ::

            result = api.get_domain(
                domain_id="example",
            )
        """

        if not options:
            options = WaitForOptions()

        if not options.stop:
            options.stop = lambda res: res.status not in DOMAIN_TRANSIENT_STATUSES

        return wait_for_resource(
            fetcher=self.get_domain,
            options=options,
            args={
                "domain_id": domain_id,
                "region": region,
            },
        )

    def list_domains(
        self,
        *,
        region: Optional[Region] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        project_id: Optional[str] = None,
        status: Optional[List[DomainStatus]] = None,
        organization_id: Optional[str] = None,
        name: Optional[str] = None,
    ) -> ListDomainsResponse:
        """
        List domains.
        Retrieve domains in a specific Project or in a specific Organization using the `region` parameter.
        :param region: Region to target. If none is passed will use default region from the config.
        :param page: Requested page number. Value must be greater or equal to 1.
        :param page_size: Requested page size. Value must be between 1 and 1000.
        :param project_id: (Optional) ID of the Project in which to list the domains.
        :param status: (Optional) List domains under specific statuses.
        :param organization_id: (Optional) ID of the Organization in which to list the domains.
        :param name: (Optional) Names of the domains to list.
        :return: :class:`ListDomainsResponse <ListDomainsResponse>`

        Usage:
        ::

            result = api.list_domains()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "GET",
            f"/transactional-email/v1alpha1/regions/{param_region}/domains",
            params={
                "name": name,
                "organization_id": organization_id
                or self.client.default_organization_id,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
                "status": status,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListDomainsResponse(res.json())

    def list_domains_all(
        self,
        *,
        region: Optional[Region] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        project_id: Optional[str] = None,
        status: Optional[List[DomainStatus]] = None,
        organization_id: Optional[str] = None,
        name: Optional[str] = None,
    ) -> List[Domain]:
        """
        List domains.
        Retrieve domains in a specific Project or in a specific Organization using the `region` parameter.
        :param region: Region to target. If none is passed will use default region from the config.
        :param page: Requested page number. Value must be greater or equal to 1.
        :param page_size: Requested page size. Value must be between 1 and 1000.
        :param project_id: (Optional) ID of the Project in which to list the domains.
        :param status: (Optional) List domains under specific statuses.
        :param organization_id: (Optional) ID of the Organization in which to list the domains.
        :param name: (Optional) Names of the domains to list.
        :return: :class:`List[Domain] <List[Domain]>`

        Usage:
        ::

            result = api.list_domains_all()
        """

        return fetch_all_pages(
            type=ListDomainsResponse,
            key="domains",
            fetcher=self.list_domains,
            args={
                "region": region,
                "page": page,
                "page_size": page_size,
                "project_id": project_id,
                "status": status,
                "organization_id": organization_id,
                "name": name,
            },
        )

    def revoke_domain(
        self,
        *,
        domain_id: str,
        region: Optional[Region] = None,
    ) -> Domain:
        """
        Delete a domain.
        You must specify the domain you want to delete by the `region` and `domain_id`. Deleting a domain is permanent and cannot be undone.
        :param domain_id: ID of the domain to delete.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`Domain <Domain>`

        Usage:
        ::

            result = api.revoke_domain(
                domain_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_domain_id = validate_path_param("domain_id", domain_id)

        res = self._request(
            "POST",
            f"/transactional-email/v1alpha1/regions/{param_region}/domains/{param_domain_id}/revoke",
            body={},
        )

        self._throw_on_error(res)
        return unmarshal_Domain(res.json())

    def check_domain(
        self,
        *,
        domain_id: str,
        region: Optional[Region] = None,
    ) -> Domain:
        """
        Domain DNS check.
        Perform an immediate DNS check of a domain using the `region` and `domain_id` parameters.
        :param domain_id: ID of the domain to check.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`Domain <Domain>`

        Usage:
        ::

            result = api.check_domain(
                domain_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_domain_id = validate_path_param("domain_id", domain_id)

        res = self._request(
            "POST",
            f"/transactional-email/v1alpha1/regions/{param_region}/domains/{param_domain_id}/check",
            body={},
        )

        self._throw_on_error(res)
        return unmarshal_Domain(res.json())

    def get_domain_last_status(
        self,
        *,
        domain_id: str,
        region: Optional[Region] = None,
    ) -> DomainLastStatus:
        """
        Display SPF and DKIM records status and potential errors.
        Display SPF and DKIM records status and potential errors, including the found records to make debugging easier.
        :param domain_id: ID of the domain to delete.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`DomainLastStatus <DomainLastStatus>`

        Usage:
        ::

            result = api.get_domain_last_status(
                domain_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_domain_id = validate_path_param("domain_id", domain_id)

        res = self._request(
            "GET",
            f"/transactional-email/v1alpha1/regions/{param_region}/domains/{param_domain_id}/verification",
        )

        self._throw_on_error(res)
        return unmarshal_DomainLastStatus(res.json())

    def create_webhook(
        self,
        *,
        domain_id: str,
        name: str,
        sns_arn: str,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        event_types: Optional[List[WebhookEventType]] = None,
    ) -> Webhook:
        """
        Create a Webhook.
        Create a new Webhook triggered by a list of event types and pushed to a Scaleway SNS ARN.
        :param domain_id: ID of the Domain to watch for triggering events.
        :param name: Name of the Webhook.
        :param sns_arn: Scaleway SNS ARN topic to push the events to.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: ID of the project to which the Webhook belongs.
        :param event_types: List of event types that will trigger an event.
        :return: :class:`Webhook <Webhook>`

        Usage:
        ::

            result = api.create_webhook(
                domain_id="example",
                name="example",
                sns_arn="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/transactional-email/v1alpha1/regions/{param_region}/webhooks",
            body=marshal_CreateWebhookRequest(
                CreateWebhookRequest(
                    domain_id=domain_id,
                    name=name,
                    sns_arn=sns_arn,
                    region=region,
                    project_id=project_id,
                    event_types=event_types,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Webhook(res.json())

    def list_webhooks(
        self,
        *,
        region: Optional[Region] = None,
        order_by: Optional[ListWebhooksRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        project_id: Optional[str] = None,
        organization_id: Optional[str] = None,
        domain_id: Optional[str] = None,
    ) -> ListWebhooksResponse:
        """
        List Webhooks.
        Retrieve Webhooks in a specific Project or in a specific Organization using the `region` parameter.
        :param region: Region to target. If none is passed will use default region from the config.
        :param order_by: (Optional) List Webhooks corresponding to specific criteria.
        :param page: (Optional) Requested page number. Value must be greater or equal to 1.
        :param page_size: (Optional) Requested page size. Value must be between 1 and 100.
        :param project_id: (Optional) ID of the Project for which to list the Webhooks.
        :param organization_id: (Optional) ID of the Organization for which to list the Webhooks.
        :param domain_id: (Optional) ID of the Domain for which to list the Webhooks.
        :return: :class:`ListWebhooksResponse <ListWebhooksResponse>`

        Usage:
        ::

            result = api.list_webhooks()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "GET",
            f"/transactional-email/v1alpha1/regions/{param_region}/webhooks",
            params={
                "domain_id": domain_id,
                "order_by": order_by,
                "organization_id": organization_id
                or self.client.default_organization_id,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListWebhooksResponse(res.json())

    def list_webhooks_all(
        self,
        *,
        region: Optional[Region] = None,
        order_by: Optional[ListWebhooksRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        project_id: Optional[str] = None,
        organization_id: Optional[str] = None,
        domain_id: Optional[str] = None,
    ) -> List[Webhook]:
        """
        List Webhooks.
        Retrieve Webhooks in a specific Project or in a specific Organization using the `region` parameter.
        :param region: Region to target. If none is passed will use default region from the config.
        :param order_by: (Optional) List Webhooks corresponding to specific criteria.
        :param page: (Optional) Requested page number. Value must be greater or equal to 1.
        :param page_size: (Optional) Requested page size. Value must be between 1 and 100.
        :param project_id: (Optional) ID of the Project for which to list the Webhooks.
        :param organization_id: (Optional) ID of the Organization for which to list the Webhooks.
        :param domain_id: (Optional) ID of the Domain for which to list the Webhooks.
        :return: :class:`List[Webhook] <List[Webhook]>`

        Usage:
        ::

            result = api.list_webhooks_all()
        """

        return fetch_all_pages(
            type=ListWebhooksResponse,
            key="webhooks",
            fetcher=self.list_webhooks,
            args={
                "region": region,
                "order_by": order_by,
                "page": page,
                "page_size": page_size,
                "project_id": project_id,
                "organization_id": organization_id,
                "domain_id": domain_id,
            },
        )

    def get_webhook(
        self,
        *,
        webhook_id: str,
        region: Optional[Region] = None,
    ) -> Webhook:
        """
        Get information about a Webhook.
        Retrieve information about a specific Webhook using the `webhook_id` and `region` parameters.
        :param webhook_id: ID of the Webhook to check.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`Webhook <Webhook>`

        Usage:
        ::

            result = api.get_webhook(
                webhook_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_webhook_id = validate_path_param("webhook_id", webhook_id)

        res = self._request(
            "GET",
            f"/transactional-email/v1alpha1/regions/{param_region}/webhooks/{param_webhook_id}",
        )

        self._throw_on_error(res)
        return unmarshal_Webhook(res.json())

    def update_webhook(
        self,
        *,
        webhook_id: str,
        region: Optional[Region] = None,
        name: Optional[str] = None,
        event_types: Optional[List[WebhookEventType]] = None,
        sns_arn: Optional[str] = None,
    ) -> Webhook:
        """
        Update a Webhook.
        Update a Webhook events type, SNS ARN or name.
        :param webhook_id: ID of the Webhook to update.
        :param region: Region to target. If none is passed will use default region from the config.
        :param name: Name of the Webhook to update.
        :param event_types: List of event types to update.
        :param sns_arn: Scaleway SNS ARN topic to update.
        :return: :class:`Webhook <Webhook>`

        Usage:
        ::

            result = api.update_webhook(
                webhook_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_webhook_id = validate_path_param("webhook_id", webhook_id)

        res = self._request(
            "PATCH",
            f"/transactional-email/v1alpha1/regions/{param_region}/webhooks/{param_webhook_id}",
            body=marshal_UpdateWebhookRequest(
                UpdateWebhookRequest(
                    webhook_id=webhook_id,
                    region=region,
                    name=name,
                    event_types=event_types,
                    sns_arn=sns_arn,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Webhook(res.json())

    def delete_webhook(
        self,
        *,
        webhook_id: str,
        region: Optional[Region] = None,
    ) -> None:
        """
        Delete a Webhook.
        You must specify the Webhook you want to delete by the `region` and `webhook_id`. Deleting a Webhook is permanent and cannot be undone.
        :param webhook_id: ID of the Webhook to delete.
        :param region: Region to target. If none is passed will use default region from the config.

        Usage:
        ::

            result = api.delete_webhook(
                webhook_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_webhook_id = validate_path_param("webhook_id", webhook_id)

        res = self._request(
            "DELETE",
            f"/transactional-email/v1alpha1/regions/{param_region}/webhooks/{param_webhook_id}",
        )

        self._throw_on_error(res)

    def list_webhook_events(
        self,
        *,
        webhook_id: str,
        region: Optional[Region] = None,
        order_by: Optional[ListWebhookEventsRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        email_id: Optional[str] = None,
        event_types: Optional[List[WebhookEventType]] = None,
        statuses: Optional[List[WebhookEventStatus]] = None,
        project_id: Optional[str] = None,
        organization_id: Optional[str] = None,
        domain_id: Optional[str] = None,
    ) -> ListWebhookEventsResponse:
        """
        List Webhook triggered events.
        Retrieve the list of Webhook events triggered from a specific Webhook or for a specific Project or Organization. You must specify the `region`.
        :param webhook_id: ID of the Webhook linked to the events.
        :param region: Region to target. If none is passed will use default region from the config.
        :param order_by: (Optional) List Webhook events corresponding to specific criteria.
        :param page: Requested page number. Value must be greater or equal to 1.
        :param page_size: Requested page size. Value must be between 1 and 100.
        :param email_id: ID of the email linked to the events.
        :param event_types: List of event types linked to the events.
        :param statuses: List of event statuses.
        :param project_id: ID of the webhook Project.
        :param organization_id: ID of the webhook Organization.
        :param domain_id: ID of the domain to watch for triggering events.
        :return: :class:`ListWebhookEventsResponse <ListWebhookEventsResponse>`

        Usage:
        ::

            result = api.list_webhook_events(
                webhook_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_webhook_id = validate_path_param("webhook_id", webhook_id)

        res = self._request(
            "GET",
            f"/transactional-email/v1alpha1/regions/{param_region}/webhooks/{param_webhook_id}/events",
            params={
                "domain_id": domain_id,
                "email_id": email_id,
                "event_types": event_types,
                "order_by": order_by,
                "organization_id": organization_id
                or self.client.default_organization_id,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
                "statuses": statuses,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListWebhookEventsResponse(res.json())

    def list_webhook_events_all(
        self,
        *,
        webhook_id: str,
        region: Optional[Region] = None,
        order_by: Optional[ListWebhookEventsRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        email_id: Optional[str] = None,
        event_types: Optional[List[WebhookEventType]] = None,
        statuses: Optional[List[WebhookEventStatus]] = None,
        project_id: Optional[str] = None,
        organization_id: Optional[str] = None,
        domain_id: Optional[str] = None,
    ) -> List[WebhookEvent]:
        """
        List Webhook triggered events.
        Retrieve the list of Webhook events triggered from a specific Webhook or for a specific Project or Organization. You must specify the `region`.
        :param webhook_id: ID of the Webhook linked to the events.
        :param region: Region to target. If none is passed will use default region from the config.
        :param order_by: (Optional) List Webhook events corresponding to specific criteria.
        :param page: Requested page number. Value must be greater or equal to 1.
        :param page_size: Requested page size. Value must be between 1 and 100.
        :param email_id: ID of the email linked to the events.
        :param event_types: List of event types linked to the events.
        :param statuses: List of event statuses.
        :param project_id: ID of the webhook Project.
        :param organization_id: ID of the webhook Organization.
        :param domain_id: ID of the domain to watch for triggering events.
        :return: :class:`List[WebhookEvent] <List[WebhookEvent]>`

        Usage:
        ::

            result = api.list_webhook_events_all(
                webhook_id="example",
            )
        """

        return fetch_all_pages(
            type=ListWebhookEventsResponse,
            key="webhook_events",
            fetcher=self.list_webhook_events,
            args={
                "webhook_id": webhook_id,
                "region": region,
                "order_by": order_by,
                "page": page,
                "page_size": page_size,
                "email_id": email_id,
                "event_types": event_types,
                "statuses": statuses,
                "project_id": project_id,
                "organization_id": organization_id,
                "domain_id": domain_id,
            },
        )



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import AttachFailoverIPToMacAddressRequestMacType
from .types import BMCAccessStatus
from .content import BMC_ACCESS_TRANSIENT_STATUSES
from .types import BackupStatus
from .types import FailoverBlockVersion
from .types import FailoverIPInterfaceType
from .types import FailoverIPStatus
from .types import FailoverIPVersion
from .types import GetRpnStatusResponseStatus
from .types import IPSemantic
from .types import IPStatus
from .types import IPVersion
from .types import IPv6BlockDelegationStatus
from .content import I_PV6_BLOCK_DELEGATION_TRANSIENT_STATUSES
from .types import InvoicePaymentMethod
from .types import InvoiceStatus
from .types import ListFailoverIPsRequestOrderBy
from .types import ListInvoicesRequestOrderBy
from .types import ListOSRequestOrderBy
from .types import ListOffersRequestOrderBy
from .types import ListRefundsRequestOrderBy
from .types import ListRpnCapableSanServersRequestOrderBy
from .types import ListRpnCapableServersRequestOrderBy
from .types import ListRpnGroupMembersRequestOrderBy
from .types import ListRpnGroupsRequestOrderBy
from .types import ListRpnInvitesRequestOrderBy
from .types import ListRpnSansRequestOrderBy
from .types import ListRpnServerCapabilitiesRequestOrderBy
from .types import ListRpnV2CapableResourcesRequestOrderBy
from .types import ListRpnV2GroupLogsRequestOrderBy
from .types import ListRpnV2GroupsRequestOrderBy
from .types import ListRpnV2MembersRequestOrderBy
from .types import ListRpnV2MembersRequestType
from .types import ListServerDisksRequestOrderBy
from .types import ListServerEventsRequestOrderBy
from .types import ListServersRequestOrderBy
from .types import ListServicesRequestOrderBy
from .types import LogAction
from .types import LogStatus
from .types import MemoryType
from .types import NetworkInterfaceInterfaceType
from .types import OSArch
from .types import OSType
from .types import OfferAntiDosInfoType
from .types import OfferCatalog
from .types import OfferPaymentFrequency
from .types import OfferSANInfoType
from .types import OfferServerInfoStock
from .types import PartitionFileSystem
from .types import PartitionType
from .types import RaidArrayRaidLevel
from .types import RefundMethod
from .types import RefundStatus
from .types import RescueProtocol
from .types import RpnGroupMemberStatus
from .content import RPN_GROUP_MEMBER_TRANSIENT_STATUSES
from .types import RpnGroupType
from .types import RpnSanIpType
from .types import RpnSanStatus
from .content import RPN_SAN_TRANSIENT_STATUSES
from .types import RpnV2GroupStatus
from .content import RPN_V2_GROUP_TRANSIENT_STATUSES
from .types import RpnV2GroupType
from .types import RpnV2MemberStatus
from .content import RPN_V2_MEMBER_TRANSIENT_STATUSES
from .types import ServerDiskType
from .types import ServerInstallStatus
from .content import SERVER_INSTALL_TRANSIENT_STATUSES
from .types import ServerStatus
from .content import SERVER_TRANSIENT_STATUSES
from .types import ServiceLevelLevel
from .types import ServiceProvisioningStatus
from .content import SERVICE_PROVISIONING_TRANSIENT_STATUSES
from .types import ServiceType
from .types import OfferAntiDosInfo
from .types import OfferBackupInfo
from .types import OfferBandwidthInfo
from .types import OfferLicenseInfo
from .types import OfferRPNInfo
from .types import OfferSANInfo
from .types import OfferStorageInfo
from .types import IP
from .types import Offer
from .types import NetworkInterface
from .types import OS
from .types import ServerLocation
from .types import ServerOption
from .types import ServiceLevel
from .types import RpnSan
from .types import RpnGroup
from .types import RpnV2GroupSubnet
from .types import Server
from .types import FailoverBlock
from .types import RpnSanIpRpnV2Group
from .types import RpnSanIpServer
from .types import RpnSanServer
from .types import RpnV2Group
from .types import RpnV2Member
from .types import ServerDisk
from .types import Service
from .types import GetIPv6BlockQuotasResponseQuota
from .types import InstallPartition
from .types import FailoverIP
from .types import ListIPv6BlockSubnetsAvailableResponseSubnet
from .types import InvoiceSummary
from .types import RpnSanIp
from .types import RefundSummary
from .types import RpnGroupMember
from .types import RpnSanSummary
from .types import RpnServerCapability
from .types import Log
from .types import ServerEvent
from .types import ServerSummary
from .types import CPU
from .types import Disk
from .types import Memory
from .types import PersistentMemory
from .types import RaidController
from .types import RaidArray
from .types import Partition
from .types import UpdatableRaidArray
from .types import AttachFailoverIPToMacAddressRequest
from .types import AttachFailoverIPsRequest
from .types import BMCAccess
from .types import Backup
from .types import BillingApiCanOrderRequest
from .types import BillingApiDownloadInvoiceRequest
from .types import BillingApiDownloadRefundRequest
from .types import BillingApiGetInvoiceRequest
from .types import BillingApiGetRefundRequest
from .types import BillingApiListInvoicesRequest
from .types import BillingApiListRefundsRequest
from .types import CanOrderResponse
from .types import CancelServerInstallRequest
from .types import CreateFailoverIPsRequest
from .types import CreateFailoverIPsResponse
from .types import CreateServerRequest
from .types import DeleteFailoverIPRequest
from .types import DeleteServerRequest
from .types import DeleteServiceRequest
from .types import DetachFailoverIPFromMacAddressRequest
from .types import DetachFailoverIPsRequest
from .types import GetBMCAccessRequest
from .types import GetFailoverIPRequest
from .types import GetIPv6BlockQuotasResponse
from .types import GetOSRequest
from .types import GetOfferRequest
from .types import GetOrderedServiceRequest
from .types import GetRaidRequest
from .types import GetRemainingQuotaRequest
from .types import GetRemainingQuotaResponse
from .types import GetRescueRequest
from .types import GetRpnStatusResponse
from .types import GetServerBackupRequest
from .types import GetServerDefaultPartitioningRequest
from .types import GetServerInstallRequest
from .types import GetServerRequest
from .types import GetServiceRequest
from .types import IPv6Block
from .types import IPv6BlockApiCreateIPv6BlockRequest
from .types import IPv6BlockApiCreateIPv6BlockSubnetRequest
from .types import IPv6BlockApiDeleteIPv6BlockRequest
from .types import IPv6BlockApiGetIPv6BlockQuotasRequest
from .types import IPv6BlockApiGetIPv6BlockRequest
from .types import IPv6BlockApiListIPv6BlockSubnetsAvailableRequest
from .types import IPv6BlockApiUpdateIPv6BlockRequest
from .types import InstallServerRequest
from .types import Invoice
from .types import ListFailoverIPsRequest
from .types import ListFailoverIPsResponse
from .types import ListIPv6BlockSubnetsAvailableResponse
from .types import ListInvoicesResponse
from .types import ListIpsResponse
from .types import ListOSRequest
from .types import ListOSResponse
from .types import ListOffersRequest
from .types import ListOffersResponse
from .types import ListRefundsResponse
from .types import ListRpnCapableSanServersResponse
from .types import ListRpnCapableServersResponse
from .types import ListRpnGroupMembersResponse
from .types import ListRpnGroupsResponse
from .types import ListRpnInvitesResponse
from .types import ListRpnSansResponse
from .types import ListRpnServerCapabilitiesResponse
from .types import ListRpnV2CapableResourcesResponse
from .types import ListRpnV2GroupLogsResponse
from .types import ListRpnV2GroupsResponse
from .types import ListRpnV2MembersResponse
from .types import ListServerDisksRequest
from .types import ListServerDisksResponse
from .types import ListServerEventsRequest
from .types import ListServerEventsResponse
from .types import ListServersRequest
from .types import ListServersResponse
from .types import ListServicesRequest
from .types import ListServicesResponse
from .types import ListSubscribableServerOptionsRequest
from .types import ListSubscribableServerOptionsResponse
from .types import OfferFailoverBlockInfo
from .types import OfferFailoverIpInfo
from .types import OfferServerInfo
from .types import OfferServiceLevelInfo
from .types import Raid
from .types import RebootServerRequest
from .types import Refund
from .types import Rescue
from .types import RpnApiGetRpnStatusRequest
from .types import RpnApiListRpnServerCapabilitiesRequest
from .types import RpnSanApiAddIpRequest
from .types import RpnSanApiCreateRpnSanRequest
from .types import RpnSanApiDeleteRpnSanRequest
from .types import RpnSanApiGetRpnSanRequest
from .types import RpnSanApiListAvailableIpsRequest
from .types import RpnSanApiListIpsRequest
from .types import RpnSanApiListRpnSansRequest
from .types import RpnSanApiRemoveIpRequest
from .types import RpnV1ApiAcceptRpnInviteRequest
from .types import RpnV1ApiAddRpnGroupMembersRequest
from .types import RpnV1ApiCreateRpnGroupRequest
from .types import RpnV1ApiDeleteRpnGroupMembersRequest
from .types import RpnV1ApiDeleteRpnGroupRequest
from .types import RpnV1ApiGetRpnGroupRequest
from .types import RpnV1ApiLeaveRpnGroupRequest
from .types import RpnV1ApiListRpnCapableSanServersRequest
from .types import RpnV1ApiListRpnCapableServersRequest
from .types import RpnV1ApiListRpnGroupMembersRequest
from .types import RpnV1ApiListRpnGroupsRequest
from .types import RpnV1ApiListRpnInvitesRequest
from .types import RpnV1ApiRefuseRpnInviteRequest
from .types import RpnV1ApiRpnGroupInviteRequest
from .types import RpnV1ApiUpdateRpnGroupNameRequest
from .types import RpnV2ApiAddRpnV2MembersRequest
from .types import RpnV2ApiCreateRpnV2GroupRequest
from .types import RpnV2ApiDeleteRpnV2GroupRequest
from .types import RpnV2ApiDeleteRpnV2MembersRequest
from .types import RpnV2ApiDisableRpnV2GroupCompatibilityRequest
from .types import RpnV2ApiEnableRpnV2GroupCompatibilityRequest
from .types import RpnV2ApiGetRpnV2GroupRequest
from .types import RpnV2ApiListRpnV2CapableResourcesRequest
from .types import RpnV2ApiListRpnV2GroupLogsRequest
from .types import RpnV2ApiListRpnV2GroupsRequest
from .types import RpnV2ApiListRpnV2MembersRequest
from .types import RpnV2ApiUpdateRpnV2GroupNameRequest
from .types import RpnV2ApiUpdateRpnV2VlanForMembersRequest
from .types import ServerDefaultPartitioning
from .types import ServerInstall
from .types import StartBMCAccessRequest
from .types import StartRescueRequest
from .types import StartServerRequest
from .types import StopBMCAccessRequest
from .types import StopRescueRequest
from .types import StopServerRequest
from .types import SubscribeServerOptionRequest
from .types import SubscribeStorageOptionsRequest
from .types import SubscribeStorageOptionsResponse
from .types import UpdateRaidRequest
from .types import UpdateReverseRequest
from .types import UpdateServerBackupRequest
from .types import UpdateServerRequest
from .types import UpdateServerTagsRequest
from .api import DediboxV1API
from .api import DediboxV1BillingAPI
from .api import DediboxV1IPv6BlockAPI
from .api import DediboxV1RpnAPI
from .api import DediboxV1RpnSanAPI
from .api import DediboxV1RpnV1API
from .api import DediboxV1RpnV2API

__all__ = [
    "AttachFailoverIPToMacAddressRequestMacType",
    "BMCAccessStatus",
    "BMC_ACCESS_TRANSIENT_STATUSES",
    "BackupStatus",
    "FailoverBlockVersion",
    "FailoverIPInterfaceType",
    "FailoverIPStatus",
    "FailoverIPVersion",
    "GetRpnStatusResponseStatus",
    "IPSemantic",
    "IPStatus",
    "IPVersion",
    "IPv6BlockDelegationStatus",
    "I_PV6_BLOCK_DELEGATION_TRANSIENT_STATUSES",
    "InvoicePaymentMethod",
    "InvoiceStatus",
    "ListFailoverIPsRequestOrderBy",
    "ListInvoicesRequestOrderBy",
    "ListOSRequestOrderBy",
    "ListOffersRequestOrderBy",
    "ListRefundsRequestOrderBy",
    "ListRpnCapableSanServersRequestOrderBy",
    "ListRpnCapableServersRequestOrderBy",
    "ListRpnGroupMembersRequestOrderBy",
    "ListRpnGroupsRequestOrderBy",
    "ListRpnInvitesRequestOrderBy",
    "ListRpnSansRequestOrderBy",
    "ListRpnServerCapabilitiesRequestOrderBy",
    "ListRpnV2CapableResourcesRequestOrderBy",
    "ListRpnV2GroupLogsRequestOrderBy",
    "ListRpnV2GroupsRequestOrderBy",
    "ListRpnV2MembersRequestOrderBy",
    "ListRpnV2MembersRequestType",
    "ListServerDisksRequestOrderBy",
    "ListServerEventsRequestOrderBy",
    "ListServersRequestOrderBy",
    "ListServicesRequestOrderBy",
    "LogAction",
    "LogStatus",
    "MemoryType",
    "NetworkInterfaceInterfaceType",
    "OSArch",
    "OSType",
    "OfferAntiDosInfoType",
    "OfferCatalog",
    "OfferPaymentFrequency",
    "OfferSANInfoType",
    "OfferServerInfoStock",
    "PartitionFileSystem",
    "PartitionType",
    "RaidArrayRaidLevel",
    "RefundMethod",
    "RefundStatus",
    "RescueProtocol",
    "RpnGroupMemberStatus",
    "RPN_GROUP_MEMBER_TRANSIENT_STATUSES",
    "RpnGroupType",
    "RpnSanIpType",
    "RpnSanStatus",
    "RPN_SAN_TRANSIENT_STATUSES",
    "RpnV2GroupStatus",
    "RPN_V2_GROUP_TRANSIENT_STATUSES",
    "RpnV2GroupType",
    "RpnV2MemberStatus",
    "RPN_V2_MEMBER_TRANSIENT_STATUSES",
    "ServerDiskType",
    "ServerInstallStatus",
    "SERVER_INSTALL_TRANSIENT_STATUSES",
    "ServerStatus",
    "SERVER_TRANSIENT_STATUSES",
    "ServiceLevelLevel",
    "ServiceProvisioningStatus",
    "SERVICE_PROVISIONING_TRANSIENT_STATUSES",
    "ServiceType",
    "OfferAntiDosInfo",
    "OfferBackupInfo",
    "OfferBandwidthInfo",
    "OfferLicenseInfo",
    "OfferRPNInfo",
    "OfferSANInfo",
    "OfferStorageInfo",
    "IP",
    "Offer",
    "NetworkInterface",
    "OS",
    "ServerLocation",
    "ServerOption",
    "ServiceLevel",
    "RpnSan",
    "RpnGroup",
    "RpnV2GroupSubnet",
    "Server",
    "FailoverBlock",
    "RpnSanIpRpnV2Group",
    "RpnSanIpServer",
    "RpnSanServer",
    "RpnV2Group",
    "RpnV2Member",
    "ServerDisk",
    "Service",
    "GetIPv6BlockQuotasResponseQuota",
    "InstallPartition",
    "FailoverIP",
    "ListIPv6BlockSubnetsAvailableResponseSubnet",
    "InvoiceSummary",
    "RpnSanIp",
    "RefundSummary",
    "RpnGroupMember",
    "RpnSanSummary",
    "RpnServerCapability",
    "Log",
    "ServerEvent",
    "ServerSummary",
    "CPU",
    "Disk",
    "Memory",
    "PersistentMemory",
    "RaidController",
    "RaidArray",
    "Partition",
    "UpdatableRaidArray",
    "AttachFailoverIPToMacAddressRequest",
    "AttachFailoverIPsRequest",
    "BMCAccess",
    "Backup",
    "BillingApiCanOrderRequest",
    "BillingApiDownloadInvoiceRequest",
    "BillingApiDownloadRefundRequest",
    "BillingApiGetInvoiceRequest",
    "BillingApiGetRefundRequest",
    "BillingApiListInvoicesRequest",
    "BillingApiListRefundsRequest",
    "CanOrderResponse",
    "CancelServerInstallRequest",
    "CreateFailoverIPsRequest",
    "CreateFailoverIPsResponse",
    "CreateServerRequest",
    "DeleteFailoverIPRequest",
    "DeleteServerRequest",
    "DeleteServiceRequest",
    "DetachFailoverIPFromMacAddressRequest",
    "DetachFailoverIPsRequest",
    "GetBMCAccessRequest",
    "GetFailoverIPRequest",
    "GetIPv6BlockQuotasResponse",
    "GetOSRequest",
    "GetOfferRequest",
    "GetOrderedServiceRequest",
    "GetRaidRequest",
    "GetRemainingQuotaRequest",
    "GetRemainingQuotaResponse",
    "GetRescueRequest",
    "GetRpnStatusResponse",
    "GetServerBackupRequest",
    "GetServerDefaultPartitioningRequest",
    "GetServerInstallRequest",
    "GetServerRequest",
    "GetServiceRequest",
    "IPv6Block",
    "IPv6BlockApiCreateIPv6BlockRequest",
    "IPv6BlockApiCreateIPv6BlockSubnetRequest",
    "IPv6BlockApiDeleteIPv6BlockRequest",
    "IPv6BlockApiGetIPv6BlockQuotasRequest",
    "IPv6BlockApiGetIPv6BlockRequest",
    "IPv6BlockApiListIPv6BlockSubnetsAvailableRequest",
    "IPv6BlockApiUpdateIPv6BlockRequest",
    "InstallServerRequest",
    "Invoice",
    "ListFailoverIPsRequest",
    "ListFailoverIPsResponse",
    "ListIPv6BlockSubnetsAvailableResponse",
    "ListInvoicesResponse",
    "ListIpsResponse",
    "ListOSRequest",
    "ListOSResponse",
    "ListOffersRequest",
    "ListOffersResponse",
    "ListRefundsResponse",
    "ListRpnCapableSanServersResponse",
    "ListRpnCapableServersResponse",
    "ListRpnGroupMembersResponse",
    "ListRpnGroupsResponse",
    "ListRpnInvitesResponse",
    "ListRpnSansResponse",
    "ListRpnServerCapabilitiesResponse",
    "ListRpnV2CapableResourcesResponse",
    "ListRpnV2GroupLogsResponse",
    "ListRpnV2GroupsResponse",
    "ListRpnV2MembersResponse",
    "ListServerDisksRequest",
    "ListServerDisksResponse",
    "ListServerEventsRequest",
    "ListServerEventsResponse",
    "ListServersRequest",
    "ListServersResponse",
    "ListServicesRequest",
    "ListServicesResponse",
    "ListSubscribableServerOptionsRequest",
    "ListSubscribableServerOptionsResponse",
    "OfferFailoverBlockInfo",
    "OfferFailoverIpInfo",
    "OfferServerInfo",
    "OfferServiceLevelInfo",
    "Raid",
    "RebootServerRequest",
    "Refund",
    "Rescue",
    "RpnApiGetRpnStatusRequest",
    "RpnApiListRpnServerCapabilitiesRequest",
    "RpnSanApiAddIpRequest",
    "RpnSanApiCreateRpnSanRequest",
    "RpnSanApiDeleteRpnSanRequest",
    "RpnSanApiGetRpnSanRequest",
    "RpnSanApiListAvailableIpsRequest",
    "RpnSanApiListIpsRequest",
    "RpnSanApiListRpnSansRequest",
    "RpnSanApiRemoveIpRequest",
    "RpnV1ApiAcceptRpnInviteRequest",
    "RpnV1ApiAddRpnGroupMembersRequest",
    "RpnV1ApiCreateRpnGroupRequest",
    "RpnV1ApiDeleteRpnGroupMembersRequest",
    "RpnV1ApiDeleteRpnGroupRequest",
    "RpnV1ApiGetRpnGroupRequest",
    "RpnV1ApiLeaveRpnGroupRequest",
    "RpnV1ApiListRpnCapableSanServersRequest",
    "RpnV1ApiListRpnCapableServersRequest",
    "RpnV1ApiListRpnGroupMembersRequest",
    "RpnV1ApiListRpnGroupsRequest",
    "RpnV1ApiListRpnInvitesRequest",
    "RpnV1ApiRefuseRpnInviteRequest",
    "RpnV1ApiRpnGroupInviteRequest",
    "RpnV1ApiUpdateRpnGroupNameRequest",
    "RpnV2ApiAddRpnV2MembersRequest",
    "RpnV2ApiCreateRpnV2GroupRequest",
    "RpnV2ApiDeleteRpnV2GroupRequest",
    "RpnV2ApiDeleteRpnV2MembersRequest",
    "RpnV2ApiDisableRpnV2GroupCompatibilityRequest",
    "RpnV2ApiEnableRpnV2GroupCompatibilityRequest",
    "RpnV2ApiGetRpnV2GroupRequest",
    "RpnV2ApiListRpnV2CapableResourcesRequest",
    "RpnV2ApiListRpnV2GroupLogsRequest",
    "RpnV2ApiListRpnV2GroupsRequest",
    "RpnV2ApiListRpnV2MembersRequest",
    "RpnV2ApiUpdateRpnV2GroupNameRequest",
    "RpnV2ApiUpdateRpnV2VlanForMembersRequest",
    "ServerDefaultPartitioning",
    "ServerInstall",
    "StartBMCAccessRequest",
    "StartRescueRequest",
    "StartServerRequest",
    "StopBMCAccessRequest",
    "StopRescueRequest",
    "StopServerRequest",
    "SubscribeServerOptionRequest",
    "SubscribeStorageOptionsRequest",
    "SubscribeStorageOptionsResponse",
    "UpdateRaidRequest",
    "UpdateReverseRequest",
    "UpdateServerBackupRequest",
    "UpdateServerRequest",
    "UpdateServerTagsRequest",
    "DediboxV1API",
    "DediboxV1BillingAPI",
    "DediboxV1IPv6BlockAPI",
    "DediboxV1RpnAPI",
    "DediboxV1RpnSanAPI",
    "DediboxV1RpnV1API",
    "DediboxV1RpnV2API",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import ListNatsAccountsRequestOrderBy
from .types import ListNatsCredentialsRequestOrderBy
from .types import ListSnsCredentialsRequestOrderBy
from .types import ListSqsCredentialsRequestOrderBy
from .types import SnsInfoStatus
from .types import SqsInfoStatus
from .types import File
from .types import SnsPermissions
from .types import SqsPermissions
from .types import NatsAccount
from .types import NatsCredentials
from .types import SnsCredentials
from .types import SqsCredentials
from .types import ListNatsAccountsResponse
from .types import ListNatsCredentialsResponse
from .types import ListSnsCredentialsResponse
from .types import ListSqsCredentialsResponse
from .types import NatsApiCreateNatsAccountRequest
from .types import NatsApiCreateNatsCredentialsRequest
from .types import NatsApiDeleteNatsAccountRequest
from .types import NatsApiDeleteNatsCredentialsRequest
from .types import NatsApiGetNatsAccountRequest
from .types import NatsApiGetNatsCredentialsRequest
from .types import NatsApiListNatsAccountsRequest
from .types import NatsApiListNatsCredentialsRequest
from .types import NatsApiUpdateNatsAccountRequest
from .types import SnsApiActivateSnsRequest
from .types import SnsApiCreateSnsCredentialsRequest
from .types import SnsApiDeactivateSnsRequest
from .types import SnsApiDeleteSnsCredentialsRequest
from .types import SnsApiGetSnsCredentialsRequest
from .types import SnsApiGetSnsInfoRequest
from .types import SnsApiListSnsCredentialsRequest
from .types import SnsApiUpdateSnsCredentialsRequest
from .types import SnsInfo
from .types import SqsApiActivateSqsRequest
from .types import SqsApiCreateSqsCredentialsRequest
from .types import SqsApiDeactivateSqsRequest
from .types import SqsApiDeleteSqsCredentialsRequest
from .types import SqsApiGetSqsCredentialsRequest
from .types import SqsApiGetSqsInfoRequest
from .types import SqsApiListSqsCredentialsRequest
from .types import SqsApiUpdateSqsCredentialsRequest
from .types import SqsInfo
from .api import MnqV1Beta1NatsAPI
from .api import MnqV1Beta1SnsAPI
from .api import MnqV1Beta1SqsAPI

__all__ = [
    "ListNatsAccountsRequestOrderBy",
    "ListNatsCredentialsRequestOrderBy",
    "ListSnsCredentialsRequestOrderBy",
    "ListSqsCredentialsRequestOrderBy",
    "SnsInfoStatus",
    "SqsInfoStatus",
    "File",
    "SnsPermissions",
    "SqsPermissions",
    "NatsAccount",
    "NatsCredentials",
    "SnsCredentials",
    "SqsCredentials",
    "ListNatsAccountsResponse",
    "ListNatsCredentialsResponse",
    "ListSnsCredentialsResponse",
    "ListSqsCredentialsResponse",
    "NatsApiCreateNatsAccountRequest",
    "NatsApiCreateNatsCredentialsRequest",
    "NatsApiDeleteNatsAccountRequest",
    "NatsApiDeleteNatsCredentialsRequest",
    "NatsApiGetNatsAccountRequest",
    "NatsApiGetNatsCredentialsRequest",
    "NatsApiListNatsAccountsRequest",
    "NatsApiListNatsCredentialsRequest",
    "NatsApiUpdateNatsAccountRequest",
    "SnsApiActivateSnsRequest",
    "SnsApiCreateSnsCredentialsRequest",
    "SnsApiDeactivateSnsRequest",
    "SnsApiDeleteSnsCredentialsRequest",
    "SnsApiGetSnsCredentialsRequest",
    "SnsApiGetSnsInfoRequest",
    "SnsApiListSnsCredentialsRequest",
    "SnsApiUpdateSnsCredentialsRequest",
    "SnsInfo",
    "SqsApiActivateSqsRequest",
    "SqsApiCreateSqsCredentialsRequest",
    "SqsApiDeactivateSqsRequest",
    "SqsApiDeleteSqsCredentialsRequest",
    "SqsApiGetSqsCredentialsRequest",
    "SqsApiGetSqsInfoRequest",
    "SqsApiListSqsCredentialsRequest",
    "SqsApiUpdateSqsCredentialsRequest",
    "SqsInfo",
    "MnqV1Beta1NatsAPI",
    "MnqV1Beta1SnsAPI",
    "MnqV1Beta1SqsAPI",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.

from typing import List, Optional

from scaleway_core.api import API
from scaleway_core.bridge import (
    Region,
)
from scaleway_core.utils import (
    WaitForOptions,
    validate_path_param,
    fetch_all_pages,
    wait_for_resource,
)
from .types import (
    ListNamesRequestOrderBy,
    ListPinsRequestOrderBy,
    ListVolumesRequestOrderBy,
    PinStatus,
    CreatePinByCIDRequest,
    CreatePinByURLRequest,
    CreateVolumeRequest,
    ExportKeyNameResponse,
    IpnsApiCreateNameRequest,
    IpnsApiImportKeyNameRequest,
    IpnsApiUpdateNameRequest,
    ListNamesResponse,
    ListPinsResponse,
    ListVolumesResponse,
    Name,
    Pin,
    ReplacePinRequest,
    ReplacePinResponse,
    UpdateVolumeRequest,
    Volume,
)
from .content import (
    NAME_TRANSIENT_STATUSES,
    PIN_TRANSIENT_STATUSES,
)
from .marshalling import (
    unmarshal_Name,
    unmarshal_Pin,
    unmarshal_Volume,
    unmarshal_ExportKeyNameResponse,
    unmarshal_ListNamesResponse,
    unmarshal_ListPinsResponse,
    unmarshal_ListVolumesResponse,
    unmarshal_ReplacePinResponse,
    marshal_CreatePinByCIDRequest,
    marshal_CreatePinByURLRequest,
    marshal_CreateVolumeRequest,
    marshal_IpnsApiCreateNameRequest,
    marshal_IpnsApiImportKeyNameRequest,
    marshal_IpnsApiUpdateNameRequest,
    marshal_ReplacePinRequest,
    marshal_UpdateVolumeRequest,
)


class IpfsV1Alpha1API(API):
    """
    IPFS Pinning service API.
    """

    def create_volume(
        self,
        *,
        name: str,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
    ) -> Volume:
        """
        Create a new volume.
        Create a new volume from a Project ID. Volume is identified by an ID and used to host pin references.
        Volume is personal (at least to your organization) even if IPFS blocks and CID are available to anyone.
        Should be the first command you made because every pin must be attached to a volume.
        :param name: Volume name.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project ID.
        :return: :class:`Volume <Volume>`

        Usage:
        ::

            result = api.create_volume(
                name="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/ipfs/v1alpha1/regions/{param_region}/volumes",
            body=marshal_CreateVolumeRequest(
                CreateVolumeRequest(
                    name=name,
                    region=region,
                    project_id=project_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Volume(res.json())

    def get_volume(
        self,
        *,
        volume_id: str,
        region: Optional[Region] = None,
    ) -> Volume:
        """
        Get information about a volume.
        Retrieve information about a specific volume.
        :param volume_id: Volume ID.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`Volume <Volume>`

        Usage:
        ::

            result = api.get_volume(
                volume_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_volume_id = validate_path_param("volume_id", volume_id)

        res = self._request(
            "GET",
            f"/ipfs/v1alpha1/regions/{param_region}/volumes/{param_volume_id}",
        )

        self._throw_on_error(res)
        return unmarshal_Volume(res.json())

    def list_volumes(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        order_by: Optional[ListVolumesRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
    ) -> ListVolumesResponse:
        """
        List all volumes by a Project ID.
        Retrieve information about all volumes from a Project ID.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project ID, only volumes belonging to this project will be listed.
        :param order_by: Sort the order of the returned volumes.
        :param page: Page number.
        :param page_size: Maximum number of volumes to return per page.
        :return: :class:`ListVolumesResponse <ListVolumesResponse>`

        Usage:
        ::

            result = api.list_volumes()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "GET",
            f"/ipfs/v1alpha1/regions/{param_region}/volumes",
            params={
                "order_by": order_by,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListVolumesResponse(res.json())

    def list_volumes_all(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        order_by: Optional[ListVolumesRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
    ) -> List[Volume]:
        """
        List all volumes by a Project ID.
        Retrieve information about all volumes from a Project ID.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project ID, only volumes belonging to this project will be listed.
        :param order_by: Sort the order of the returned volumes.
        :param page: Page number.
        :param page_size: Maximum number of volumes to return per page.
        :return: :class:`List[Volume] <List[Volume]>`

        Usage:
        ::

            result = api.list_volumes_all()
        """

        return fetch_all_pages(
            type=ListVolumesResponse,
            key="volumes",
            fetcher=self.list_volumes,
            args={
                "region": region,
                "project_id": project_id,
                "order_by": order_by,
                "page": page,
                "page_size": page_size,
            },
        )

    def update_volume(
        self,
        *,
        volume_id: str,
        region: Optional[Region] = None,
        name: Optional[str] = None,
        tags: Optional[List[str]] = None,
    ) -> Volume:
        """
        Update volume information.
        Update volume information (tag, name...).
        :param volume_id: Volume ID.
        :param region: Region to target. If none is passed will use default region from the config.
        :param name: Volume name.
        :param tags: Tags of the volume.
        :return: :class:`Volume <Volume>`

        Usage:
        ::

            result = api.update_volume(
                volume_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_volume_id = validate_path_param("volume_id", volume_id)

        res = self._request(
            "PATCH",
            f"/ipfs/v1alpha1/regions/{param_region}/volumes/{param_volume_id}",
            body=marshal_UpdateVolumeRequest(
                UpdateVolumeRequest(
                    volume_id=volume_id,
                    region=region,
                    name=name,
                    tags=tags,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Volume(res.json())

    def delete_volume(
        self,
        *,
        volume_id: str,
        region: Optional[Region] = None,
    ) -> None:
        """
        Delete an existing volume.
        Delete a volume by its ID and every pin attached to this volume. This process can take a while to conclude, depending on the size of your pinned content.
        :param volume_id: Volume ID.
        :param region: Region to target. If none is passed will use default region from the config.

        Usage:
        ::

            result = api.delete_volume(
                volume_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_volume_id = validate_path_param("volume_id", volume_id)

        res = self._request(
            "DELETE",
            f"/ipfs/v1alpha1/regions/{param_region}/volumes/{param_volume_id}",
        )

        self._throw_on_error(res)

    def create_pin_by_url(
        self,
        *,
        volume_id: str,
        url: str,
        region: Optional[Region] = None,
        name: Optional[str] = None,
    ) -> Pin:
        """
        Create a pin by URL.
        Will fetch and store the content pointed by the provided URL. The content must be available on the public IPFS network.
        The content (IPFS blocks) will be host by the pinning service until pin deletion.
        From that point, any other IPFS peer can fetch and host your content: Make sure to pin public or encrypted content.
        Many pin requests (from different users) can target the same CID.
        A pin is defined by its ID (UUID), its status (queued, pinning, pinned or failed) and target CID.
        :param volume_id: Volume ID on which you want to pin your content.
        :param url: URL containing the content you want to pin.
        :param region: Region to target. If none is passed will use default region from the config.
        :param name: Pin name.
        :return: :class:`Pin <Pin>`

        Usage:
        ::

            result = api.create_pin_by_url(
                volume_id="example",
                url="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/ipfs/v1alpha1/regions/{param_region}/pins/create-by-url",
            body=marshal_CreatePinByURLRequest(
                CreatePinByURLRequest(
                    volume_id=volume_id,
                    url=url,
                    region=region,
                    name=name,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Pin(res.json())

    def create_pin_by_cid(
        self,
        *,
        volume_id: str,
        cid: str,
        region: Optional[Region] = None,
        origins: Optional[List[str]] = None,
        name: Optional[str] = None,
    ) -> Pin:
        """
        Create a pin by CID.
        Will fetch and store the content pointed by the provided CID. The content must be available on the public IPFS network.
        The content (IPFS blocks) will be host by the pinning service until pin deletion.
        From that point, any other IPFS peer can fetch and host your content: Make sure to pin public or encrypted content.
        Many pin requests (from different users) can target the same CID.
        A pin is defined by its ID (UUID), its status (queued, pinning, pinned or failed) and target CID.
        :param volume_id: Volume ID on which you want to pin your content.
        :param cid: CID containing the content you want to pin.
        :param region: Region to target. If none is passed will use default region from the config.
        :param origins: Node containing the content you want to pin.
        :param name: Pin name.
        :return: :class:`Pin <Pin>`

        Usage:
        ::

            result = api.create_pin_by_cid(
                volume_id="example",
                cid="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/ipfs/v1alpha1/regions/{param_region}/pins/create-by-cid",
            body=marshal_CreatePinByCIDRequest(
                CreatePinByCIDRequest(
                    volume_id=volume_id,
                    cid=cid,
                    region=region,
                    origins=origins,
                    name=name,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Pin(res.json())

    def replace_pin(
        self,
        *,
        volume_id: str,
        pin_id: str,
        cid: str,
        region: Optional[Region] = None,
        name: Optional[str] = None,
        origins: Optional[List[str]] = None,
    ) -> ReplacePinResponse:
        """
        Replace pin by CID.
        Deletes the given resource ID and pins the new CID in its place.
        Will fetch and store the content pointed by the provided CID. The content must be available on the public IPFS network.
        The content (IPFS blocks) is hosted by the pinning service until the pin is deleted.
        While the content is available any other IPFS peer can fetch and host your content. For this reason, we recommend that you pin either public or encrypted content.
        Several different pin requests can target the same CID.
        A pin is defined by its ID (UUID), its status (queued, pinning, pinned or failed) and target CID.
        :param volume_id: Volume ID.
        :param pin_id: Pin ID whose information you wish to replace.
        :param cid: New CID you want to pin in place of the old one.
        :param region: Region to target. If none is passed will use default region from the config.
        :param name: New name to replace.
        :param origins: Node containing the content you want to pin.
        :return: :class:`ReplacePinResponse <ReplacePinResponse>`

        Usage:
        ::

            result = api.replace_pin(
                volume_id="example",
                pin_id="example",
                cid="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_pin_id = validate_path_param("pin_id", pin_id)

        res = self._request(
            "POST",
            f"/ipfs/v1alpha1/regions/{param_region}/pins/{param_pin_id}/replace",
            body=marshal_ReplacePinRequest(
                ReplacePinRequest(
                    volume_id=volume_id,
                    pin_id=pin_id,
                    cid=cid,
                    region=region,
                    name=name,
                    origins=origins,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_ReplacePinResponse(res.json())

    def get_pin(
        self,
        *,
        volume_id: str,
        pin_id: str,
        region: Optional[Region] = None,
    ) -> Pin:
        """
        Get pin information.
        Retrieve information about the provided **pin ID**, such as status, last modification, and CID.
        :param volume_id: Volume ID.
        :param pin_id: Pin ID of which you want to obtain information.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`Pin <Pin>`

        Usage:
        ::

            result = api.get_pin(
                volume_id="example",
                pin_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_pin_id = validate_path_param("pin_id", pin_id)

        res = self._request(
            "GET",
            f"/ipfs/v1alpha1/regions/{param_region}/pins/{param_pin_id}",
            params={
                "volume_id": volume_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_Pin(res.json())

    def wait_for_pin(
        self,
        *,
        volume_id: str,
        pin_id: str,
        region: Optional[Region] = None,
        options: Optional[WaitForOptions[Pin, bool]] = None,
    ) -> Pin:
        """
        Get pin information.
        Retrieve information about the provided **pin ID**, such as status, last modification, and CID.
        :param volume_id: Volume ID.
        :param pin_id: Pin ID of which you want to obtain information.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`Pin <Pin>`

        Usage:
        ::

            result = api.get_pin(
                volume_id="example",
                pin_id="example",
            )
        """

        if not options:
            options = WaitForOptions()

        if not options.stop:
            options.stop = lambda res: res.status not in PIN_TRANSIENT_STATUSES

        return wait_for_resource(
            fetcher=self.get_pin,
            options=options,
            args={
                "volume_id": volume_id,
                "pin_id": pin_id,
                "region": region,
            },
        )

    def list_pins(
        self,
        *,
        volume_id: str,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        organization_id: Optional[str] = None,
        order_by: Optional[ListPinsRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        status: Optional[PinStatus] = None,
    ) -> ListPinsResponse:
        """
        List all pins within a volume.
        Retrieve information about all pins within a volume.
        :param volume_id: Volume ID of which you want to list the pins.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project ID.
        :param organization_id: Organization ID.
        :param order_by: Sort order of the returned Volume.
        :param page: Page number.
        :param page_size: Maximum number of volumes to return per page.
        :param status: List pins by status.
        :return: :class:`ListPinsResponse <ListPinsResponse>`

        Usage:
        ::

            result = api.list_pins(
                volume_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "GET",
            f"/ipfs/v1alpha1/regions/{param_region}/pins",
            params={
                "order_by": order_by,
                "organization_id": organization_id
                or self.client.default_organization_id,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
                "status": status,
                "volume_id": volume_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListPinsResponse(res.json())

    def list_pins_all(
        self,
        *,
        volume_id: str,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        organization_id: Optional[str] = None,
        order_by: Optional[ListPinsRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        status: Optional[PinStatus] = None,
    ) -> List[Pin]:
        """
        List all pins within a volume.
        Retrieve information about all pins within a volume.
        :param volume_id: Volume ID of which you want to list the pins.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project ID.
        :param organization_id: Organization ID.
        :param order_by: Sort order of the returned Volume.
        :param page: Page number.
        :param page_size: Maximum number of volumes to return per page.
        :param status: List pins by status.
        :return: :class:`List[Pin] <List[Pin]>`

        Usage:
        ::

            result = api.list_pins_all(
                volume_id="example",
            )
        """

        return fetch_all_pages(
            type=ListPinsResponse,
            key="pins",
            fetcher=self.list_pins,
            args={
                "volume_id": volume_id,
                "region": region,
                "project_id": project_id,
                "organization_id": organization_id,
                "order_by": order_by,
                "page": page,
                "page_size": page_size,
                "status": status,
            },
        )

    def delete_pin(
        self,
        *,
        volume_id: str,
        pin_id: str,
        region: Optional[Region] = None,
    ) -> None:
        """
        Create an unpin request.
        An unpin request means that you no longer own the content.
        This content can therefore be removed and no longer provided on the IPFS network.
        :param volume_id: Volume ID.
        :param pin_id: Pin ID you want to remove from the volume.
        :param region: Region to target. If none is passed will use default region from the config.

        Usage:
        ::

            result = api.delete_pin(
                volume_id="example",
                pin_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_pin_id = validate_path_param("pin_id", pin_id)

        res = self._request(
            "DELETE",
            f"/ipfs/v1alpha1/regions/{param_region}/pins/{param_pin_id}",
            params={
                "volume_id": volume_id,
            },
        )

        self._throw_on_error(res)


class IpfsV1Alpha1IpnsAPI(API):
    """ """

    def create_name(
        self,
        *,
        name: str,
        value: str,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
    ) -> Name:
        """
        Create a new name.
        You can use the `ipns key` command to list and generate more names and their respective keys.
        :param name: Name for your records.
        :param value: Value you want to associate with your records, CID or IPNS key.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project ID.
        :return: :class:`Name <Name>`

        Usage:
        ::

            result = api.create_name(
                name="example",
                value="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/ipfs/v1alpha1/regions/{param_region}/names",
            body=marshal_IpnsApiCreateNameRequest(
                IpnsApiCreateNameRequest(
                    name=name,
                    value=value,
                    region=region,
                    project_id=project_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Name(res.json())

    def get_name(
        self,
        *,
        name_id: str,
        region: Optional[Region] = None,
    ) -> Name:
        """
        Get information about a name.
        Retrieve information about a specific name.
        :param name_id: Name ID whose information you want to retrieve.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`Name <Name>`

        Usage:
        ::

            result = api.get_name(
                name_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_name_id = validate_path_param("name_id", name_id)

        res = self._request(
            "GET",
            f"/ipfs/v1alpha1/regions/{param_region}/names/{param_name_id}",
        )

        self._throw_on_error(res)
        return unmarshal_Name(res.json())

    def wait_for_name(
        self,
        *,
        name_id: str,
        region: Optional[Region] = None,
        options: Optional[WaitForOptions[Name, bool]] = None,
    ) -> Name:
        """
        Get information about a name.
        Retrieve information about a specific name.
        :param name_id: Name ID whose information you want to retrieve.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`Name <Name>`

        Usage:
        ::

            result = api.get_name(
                name_id="example",
            )
        """

        if not options:
            options = WaitForOptions()

        if not options.stop:
            options.stop = lambda res: res.status not in NAME_TRANSIENT_STATUSES

        return wait_for_resource(
            fetcher=self.get_name,
            options=options,
            args={
                "name_id": name_id,
                "region": region,
            },
        )

    def delete_name(
        self,
        *,
        name_id: str,
        region: Optional[Region] = None,
    ) -> None:
        """
        Delete an existing name.
        Delete a name by its ID.
        :param name_id: Name ID you wish to delete.
        :param region: Region to target. If none is passed will use default region from the config.

        Usage:
        ::

            result = api.delete_name(
                name_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_name_id = validate_path_param("name_id", name_id)

        res = self._request(
            "DELETE",
            f"/ipfs/v1alpha1/regions/{param_region}/names/{param_name_id}",
        )

        self._throw_on_error(res)

    def list_names(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        organization_id: Optional[str] = None,
        order_by: Optional[ListNamesRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
    ) -> ListNamesResponse:
        """
        List all names by a Project ID.
        Retrieve information about all names from a Project ID.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project ID.
        :param organization_id: Organization ID.
        :param order_by: Sort the order of the returned names.
        :param page: Page number.
        :param page_size: Maximum number of names to return per page.
        :return: :class:`ListNamesResponse <ListNamesResponse>`

        Usage:
        ::

            result = api.list_names()
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "GET",
            f"/ipfs/v1alpha1/regions/{param_region}/names",
            params={
                "order_by": order_by,
                "organization_id": organization_id
                or self.client.default_organization_id,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListNamesResponse(res.json())

    def list_names_all(
        self,
        *,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
        organization_id: Optional[str] = None,
        order_by: Optional[ListNamesRequestOrderBy] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
    ) -> List[Name]:
        """
        List all names by a Project ID.
        Retrieve information about all names from a Project ID.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project ID.
        :param organization_id: Organization ID.
        :param order_by: Sort the order of the returned names.
        :param page: Page number.
        :param page_size: Maximum number of names to return per page.
        :return: :class:`List[Name] <List[Name]>`

        Usage:
        ::

            result = api.list_names_all()
        """

        return fetch_all_pages(
            type=ListNamesResponse,
            key="names",
            fetcher=self.list_names,
            args={
                "region": region,
                "project_id": project_id,
                "organization_id": organization_id,
                "order_by": order_by,
                "page": page,
                "page_size": page_size,
            },
        )

    def update_name(
        self,
        *,
        name_id: str,
        region: Optional[Region] = None,
        name: Optional[str] = None,
        tags: Optional[List[str]] = None,
        value: Optional[str] = None,
    ) -> Name:
        """
        Update name information.
        Update name information (CID, tag, name...).
        :param name_id: Name ID you wish to update.
        :param region: Region to target. If none is passed will use default region from the config.
        :param name: New name you want to associate with your record.
        :param tags: New tags you want to associate with your record.
        :param value: Value you want to associate with your records, CID or IPNS key.
        :return: :class:`Name <Name>`

        Usage:
        ::

            result = api.update_name(
                name_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_name_id = validate_path_param("name_id", name_id)

        res = self._request(
            "PATCH",
            f"/ipfs/v1alpha1/regions/{param_region}/names/{param_name_id}",
            body=marshal_IpnsApiUpdateNameRequest(
                IpnsApiUpdateNameRequest(
                    name_id=name_id,
                    region=region,
                    name=name,
                    tags=tags,
                    value=value,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Name(res.json())

    def export_key_name(
        self,
        *,
        name_id: str,
        region: Optional[Region] = None,
    ) -> ExportKeyNameResponse:
        """
        Export your private key.
        Export a private key by its ID.
        :param name_id: Name ID whose keys you want to export.
        :param region: Region to target. If none is passed will use default region from the config.
        :return: :class:`ExportKeyNameResponse <ExportKeyNameResponse>`

        Usage:
        ::

            result = api.export_key_name(
                name_id="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )
        param_name_id = validate_path_param("name_id", name_id)

        res = self._request(
            "GET",
            f"/ipfs/v1alpha1/regions/{param_region}/names/{param_name_id}/export-key",
        )

        self._throw_on_error(res)
        return unmarshal_ExportKeyNameResponse(res.json())

    def import_key_name(
        self,
        *,
        name: str,
        private_key: str,
        value: str,
        region: Optional[Region] = None,
        project_id: Optional[str] = None,
    ) -> Name:
        """
        Import your private key.
        Import a private key.
        :param name: Name for your records.
        :param private_key: Base64 private key.
        :param value: Value you want to associate with your records, CID or IPNS key.
        :param region: Region to target. If none is passed will use default region from the config.
        :param project_id: Project ID.
        :return: :class:`Name <Name>`

        Usage:
        ::

            result = api.import_key_name(
                name="example",
                private_key="example",
                value="example",
            )
        """

        param_region = validate_path_param(
            "region", region or self.client.default_region
        )

        res = self._request(
            "POST",
            f"/ipfs/v1alpha1/regions/{param_region}/names/import-key",
            body=marshal_IpnsApiImportKeyNameRequest(
                IpnsApiImportKeyNameRequest(
                    name=name,
                    private_key=private_key,
                    value=value,
                    region=region,
                    project_id=project_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Name(res.json())



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from .types import ListSnapshotsRequestOrderBy
from .types import ListVolumesRequestOrderBy
from .types import ReferenceStatus
from .content import REFERENCE_TRANSIENT_STATUSES
from .types import ReferenceType
from .types import SnapshotStatus
from .content import SNAPSHOT_TRANSIENT_STATUSES
from .types import StorageClass
from .types import VolumeStatus
from .content import VOLUME_TRANSIENT_STATUSES
from .types import Reference
from .types import SnapshotParentVolume
from .types import VolumeSpecifications
from .types import CreateVolumeRequestFromEmpty
from .types import CreateVolumeRequestFromSnapshot
from .types import Snapshot
from .types import VolumeType
from .types import Volume
from .types import CreateSnapshotRequest
from .types import CreateVolumeRequest
from .types import DeleteSnapshotRequest
from .types import DeleteVolumeRequest
from .types import ExportSnapshotToObjectStorageRequest
from .types import GetSnapshotRequest
from .types import GetVolumeRequest
from .types import ImportSnapshotFromObjectStorageRequest
from .types import ImportSnapshotFromS3Request
from .types import ListSnapshotsRequest
from .types import ListSnapshotsResponse
from .types import ListVolumeTypesRequest
from .types import ListVolumeTypesResponse
from .types import ListVolumesRequest
from .types import ListVolumesResponse
from .types import UpdateSnapshotRequest
from .types import UpdateVolumeRequest
from .api import BlockV1Alpha1API

__all__ = [
    "ListSnapshotsRequestOrderBy",
    "ListVolumesRequestOrderBy",
    "ReferenceStatus",
    "REFERENCE_TRANSIENT_STATUSES",
    "ReferenceType",
    "SnapshotStatus",
    "SNAPSHOT_TRANSIENT_STATUSES",
    "StorageClass",
    "VolumeStatus",
    "VOLUME_TRANSIENT_STATUSES",
    "Reference",
    "SnapshotParentVolume",
    "VolumeSpecifications",
    "CreateVolumeRequestFromEmpty",
    "CreateVolumeRequestFromSnapshot",
    "Snapshot",
    "VolumeType",
    "Volume",
    "CreateSnapshotRequest",
    "CreateVolumeRequest",
    "DeleteSnapshotRequest",
    "DeleteVolumeRequest",
    "ExportSnapshotToObjectStorageRequest",
    "GetSnapshotRequest",
    "GetVolumeRequest",
    "ImportSnapshotFromObjectStorageRequest",
    "ImportSnapshotFromS3Request",
    "ListSnapshotsRequest",
    "ListSnapshotsResponse",
    "ListVolumeTypesRequest",
    "ListVolumeTypesResponse",
    "ListVolumesRequest",
    "ListVolumesResponse",
    "UpdateSnapshotRequest",
    "UpdateVolumeRequest",
    "BlockV1Alpha1API",
]



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.
from __future__ import annotations

from dataclasses import dataclass
from datetime import datetime
from enum import Enum
from typing import List, Optional

from scaleway_core.bridge import (
    Region,
    Zone,
)
from scaleway_core.utils import (
    StrEnumMeta,
)


class ListIPsRequestOrderBy(str, Enum, metaclass=StrEnumMeta):
    CREATED_AT_DESC = "created_at_desc"
    CREATED_AT_ASC = "created_at_asc"
    UPDATED_AT_DESC = "updated_at_desc"
    UPDATED_AT_ASC = "updated_at_asc"
    ATTACHED_AT_DESC = "attached_at_desc"
    ATTACHED_AT_ASC = "attached_at_asc"

    def __str__(self) -> str:
        return str(self.value)


class ResourceType(str, Enum, metaclass=StrEnumMeta):
    UNKNOWN_TYPE = "unknown_type"
    INSTANCE_SERVER = "instance_server"
    INSTANCE_IP = "instance_ip"
    INSTANCE_PRIVATE_NIC = "instance_private_nic"
    LB_SERVER = "lb_server"
    FIP_IP = "fip_ip"
    VPC_GATEWAY = "vpc_gateway"
    VPC_GATEWAY_NETWORK = "vpc_gateway_network"
    K8S_NODE = "k8s_node"
    K8S_CLUSTER = "k8s_cluster"
    RDB_INSTANCE = "rdb_instance"
    REDIS_CLUSTER = "redis_cluster"
    BAREMETAL_SERVER = "baremetal_server"
    BAREMETAL_PRIVATE_NIC = "baremetal_private_nic"
    LLM_DEPLOYMENT = "llm_deployment"

    def __str__(self) -> str:
        return str(self.value)


@dataclass
class Resource:
    type_: ResourceType
    """
    Type of resource the IP is attached to.
    """

    id: str
    """
    ID of the resource the IP is attached to.
    """

    mac_address: Optional[str]
    """
    MAC of the resource the IP is attached to.
    """

    name: Optional[str]
    """
    When the IP is in a Private Network, then a DNS record is available to resolve the resource name to this IP.
    """


@dataclass
class Reverse:
    hostname: str
    """
    Reverse domain name.
    """

    address: Optional[str]
    """
    IP corresponding to the hostname.
    """


@dataclass
class Source:
    zonal: Optional[str]

    private_network_id: Optional[str]

    subnet_id: Optional[str]


@dataclass
class IP:
    id: str
    """
    IP ID.
    """

    address: str
    """
    IPv4 or IPv6 address in CIDR notation.
    """

    project_id: str
    """
    Scaleway Project the IP belongs to.
    """

    is_ipv6: bool
    """
    Defines whether the IP is an IPv6 (false = IPv4).
    """

    tags: List[str]
    """
    Tags for the IP.
    """

    reverses: List[Reverse]
    """
    Array of reverses associated with the IP.
    """

    region: Region
    """
    Region of the IP.
    """

    created_at: Optional[datetime]
    """
    Date the IP was booked.
    """

    updated_at: Optional[datetime]
    """
    Date the IP was last modified.
    """

    source: Optional[Source]
    """
    Source pool where the IP was booked in.
    """

    resource: Optional[Resource]
    """
    Resource which the IP is attached to.
    """

    zone: Optional[Zone]
    """
    Zone of the IP, if zonal.
    """


@dataclass
class BookIPRequest:
    source: Source
    """
    Source in which to book the IP. Not all sources are available for booking.
    """

    is_ipv6: bool
    """
    Request an IPv6 instead of an IPv4.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    project_id: Optional[str]
    """
    When creating an IP in a Private Network, the Project must match the Private Network's Project.
    """

    address: Optional[str]
    """
    The requested address should not include the subnet mask (/suffix). Note that only the Private Network source allows you to pick a specific IP. If the requested IP is already booked, then the call will fail.
    """

    tags: Optional[List[str]]
    """
    Tags for the IP.
    """


@dataclass
class GetIPRequest:
    ip_id: str
    """
    IP ID.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class ListIPsRequest:
    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    order_by: Optional[ListIPsRequestOrderBy]
    """
    Sort order of the returned IPs.
    """

    page: Optional[int]
    """
    Page number to return, from the paginated results.
    """

    page_size: Optional[int]
    """
    Maximum number of IPs to return per page.
    """

    project_id: Optional[str]
    """
    Project ID to filter for. Only IPs belonging to this Project will be returned.
    """

    vpc_id: Optional[str]
    """
    Only IPs owned by resources in this VPC will be returned.
    """

    attached: Optional[bool]
    """
    Defines whether to filter only for IPs which are attached to a resource.
    """

    resource_id: Optional[str]
    """
    Resource ID to filter for. Only IPs attached to this resource will be returned.
    """

    resource_type: Optional[ResourceType]
    """
    Resource type to filter for. Only IPs attached to this type of resource will be returned.
    """

    mac_address: Optional[str]
    """
    MAC address to filter for. Only IPs attached to a resource with this MAC address will be returned.
    """

    tags: Optional[List[str]]
    """
    Tags to filter for, only IPs with one or more matching tags will be returned.
    """

    organization_id: Optional[str]
    """
    Organization ID to filter for. Only IPs belonging to this Organization will be returned.
    """

    is_ipv6: Optional[bool]
    """
    Defines whether to filter only for IPv4s or IPv6s.
    """

    resource_name: Optional[str]
    """
    Attached resource name to filter for, only IPs attached to a resource with this string within their name will be returned.
    """

    resource_types: Optional[List[ResourceType]]
    """
    Resource types to filter for. Only IPs attached to these types of resources will be returned.
    """

    zonal: Optional[str]

    private_network_id: Optional[str]

    subnet_id: Optional[str]


@dataclass
class ListIPsResponse:
    total_count: int

    ips: List[IP]


@dataclass
class ReleaseIPRequest:
    ip_id: str
    """
    IP ID.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """


@dataclass
class ReleaseIPSetRequest:
    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    ip_ids: Optional[List[str]]


@dataclass
class UpdateIPRequest:
    ip_id: str
    """
    IP ID.
    """

    region: Optional[Region]
    """
    Region to target. If none is passed will use default region from the config.
    """

    tags: Optional[List[str]]
    """
    Tags for the IP.
    """

    reverses: Optional[List[Reverse]]
    """
    Array of reverse domain names associated with an IP in the subnet of the current IP.
    """



# This file was automatically generated. DO NOT EDIT.
# If you have any remark or suggestion do not hesitate to open an issue.

from datetime import datetime
from typing import List, Optional

from scaleway_core.api import API
from scaleway_core.utils import (
    WaitForOptions,
    random_name,
    validate_path_param,
    fetch_all_pages,
    wait_for_resource,
)
from .types import (
    DatasourceType,
    GrafanaUserRole,
    ListDatasourcesRequestOrderBy,
    ListGrafanaUsersRequestOrderBy,
    ListPlansRequestOrderBy,
    ListTokensRequestOrderBy,
    ActivateCockpitRequest,
    Cockpit,
    CockpitMetrics,
    ContactPoint,
    CreateContactPointRequest,
    CreateDatasourceRequest,
    CreateGrafanaUserRequest,
    CreateTokenRequest,
    Datasource,
    DeactivateCockpitRequest,
    DeleteContactPointRequest,
    DeleteGrafanaUserRequest,
    DisableManagedAlertsRequest,
    EnableManagedAlertsRequest,
    GrafanaProductDashboard,
    GrafanaUser,
    ListContactPointsResponse,
    ListDatasourcesResponse,
    ListGrafanaProductDashboardsResponse,
    ListGrafanaUsersResponse,
    ListPlansResponse,
    ListTokensResponse,
    Plan,
    ResetGrafanaUserPasswordRequest,
    SelectPlanRequest,
    SelectPlanResponse,
    Token,
    TokenScopes,
    TriggerTestAlertRequest,
)
from .content import (
    COCKPIT_TRANSIENT_STATUSES,
)
from .marshalling import (
    unmarshal_ContactPoint,
    unmarshal_Datasource,
    unmarshal_GrafanaProductDashboard,
    unmarshal_GrafanaUser,
    unmarshal_Token,
    unmarshal_Cockpit,
    unmarshal_CockpitMetrics,
    unmarshal_ListContactPointsResponse,
    unmarshal_ListDatasourcesResponse,
    unmarshal_ListGrafanaProductDashboardsResponse,
    unmarshal_ListGrafanaUsersResponse,
    unmarshal_ListPlansResponse,
    unmarshal_ListTokensResponse,
    unmarshal_SelectPlanResponse,
    marshal_ActivateCockpitRequest,
    marshal_CreateContactPointRequest,
    marshal_CreateDatasourceRequest,
    marshal_CreateGrafanaUserRequest,
    marshal_CreateTokenRequest,
    marshal_DeactivateCockpitRequest,
    marshal_DeleteContactPointRequest,
    marshal_DeleteGrafanaUserRequest,
    marshal_DisableManagedAlertsRequest,
    marshal_EnableManagedAlertsRequest,
    marshal_ResetGrafanaUserPasswordRequest,
    marshal_SelectPlanRequest,
    marshal_TriggerTestAlertRequest,
)


class CockpitV1Beta1API(API):
    """
    This API allows you to manage your Scaleway Cockpit, for storing and visualizing metrics and logs.
    """

    def activate_cockpit(
        self,
        *,
        project_id: Optional[str] = None,
    ) -> Cockpit:
        """
        Activate the Cockpit of a given Project specified by the Project ID.
        :param project_id: ID of the Project the Cockpit belongs to.
        :return: :class:`Cockpit <Cockpit>`

        Usage:
        ::

            result = api.activate_cockpit()
        """

        res = self._request(
            "POST",
            "/cockpit/v1beta1/activate",
            body=marshal_ActivateCockpitRequest(
                ActivateCockpitRequest(
                    project_id=project_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Cockpit(res.json())

    def get_cockpit(
        self,
        *,
        project_id: Optional[str] = None,
    ) -> Cockpit:
        """
        Retrieve the Cockpit of a given Project specified by the Project ID.
        :param project_id: ID of the Project the Cockpit belongs to.
        :return: :class:`Cockpit <Cockpit>`

        Usage:
        ::

            result = api.get_cockpit()
        """

        res = self._request(
            "GET",
            "/cockpit/v1beta1/cockpit",
            params={
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_Cockpit(res.json())

    def wait_for_cockpit(
        self,
        *,
        project_id: Optional[str] = None,
        options: Optional[WaitForOptions[Cockpit, bool]] = None,
    ) -> Cockpit:
        """
        Retrieve the Cockpit of a given Project specified by the Project ID.
        :param project_id: ID of the Project the Cockpit belongs to.
        :return: :class:`Cockpit <Cockpit>`

        Usage:
        ::

            result = api.get_cockpit()
        """

        if not options:
            options = WaitForOptions()

        if not options.stop:
            options.stop = lambda res: res.status not in COCKPIT_TRANSIENT_STATUSES

        return wait_for_resource(
            fetcher=self.get_cockpit,
            options=options,
            args={
                "project_id": project_id,
            },
        )

    def get_cockpit_metrics(
        self,
        *,
        project_id: Optional[str] = None,
        start_date: Optional[datetime] = None,
        end_date: Optional[datetime] = None,
        metric_name: Optional[str] = None,
    ) -> CockpitMetrics:
        """
        Retrieve metrics from your Cockpit specified by the ID of the Project the Cockpit belongs to.
        :param project_id: ID of the Project the Cockpit belongs to.
        :param start_date: Desired time range's start date for the metrics.
        :param end_date: Desired time range's end date for the metrics.
        :param metric_name: Name of the metric requested.
        :return: :class:`CockpitMetrics <CockpitMetrics>`

        Usage:
        ::

            result = api.get_cockpit_metrics()
        """

        res = self._request(
            "GET",
            "/cockpit/v1beta1/cockpit/metrics",
            params={
                "end_date": end_date,
                "metric_name": metric_name,
                "project_id": project_id or self.client.default_project_id,
                "start_date": start_date,
            },
        )

        self._throw_on_error(res)
        return unmarshal_CockpitMetrics(res.json())

    def deactivate_cockpit(
        self,
        *,
        project_id: Optional[str] = None,
    ) -> Cockpit:
        """
        Deactivate the Cockpit of a given Project specified by the Project ID.
        :param project_id: ID of the Project the Cockpit belongs to.
        :return: :class:`Cockpit <Cockpit>`

        Usage:
        ::

            result = api.deactivate_cockpit()
        """

        res = self._request(
            "POST",
            "/cockpit/v1beta1/deactivate",
            body=marshal_DeactivateCockpitRequest(
                DeactivateCockpitRequest(
                    project_id=project_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Cockpit(res.json())

    def create_datasource(
        self,
        *,
        name: str,
        is_default: bool,
        project_id: Optional[str] = None,
        type_: Optional[DatasourceType] = None,
    ) -> Datasource:
        """
        Create a data source for a given Project specified by the Project ID and the data source type.
        :param name: Data source name.
        :param is_default: Specifies that the returned output is the default data source per type.
        :param project_id: ID of the Project the Cockpit belongs to.
        :param type_: Data source type.
        :return: :class:`Datasource <Datasource>`

        Usage:
        ::

            result = api.create_datasource(
                name="example",
                is_default=False,
            )
        """

        res = self._request(
            "POST",
            "/cockpit/v1beta1/datasources",
            body=marshal_CreateDatasourceRequest(
                CreateDatasourceRequest(
                    name=name,
                    is_default=is_default,
                    project_id=project_id,
                    type_=type_,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Datasource(res.json())

    def delete_datasource(
        self,
        *,
        datasource_id: str,
    ) -> None:
        """
        Delete a given data source specified by the data source ID.
        :param datasource_id: ID of the data source.

        Usage:
        ::

            result = api.delete_datasource(
                datasource_id="example",
            )
        """

        param_datasource_id = validate_path_param("datasource_id", datasource_id)

        res = self._request(
            "DELETE",
            f"/cockpit/v1beta1/datasources/{param_datasource_id}",
        )

        self._throw_on_error(res)

    def list_datasources(
        self,
        *,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        order_by: Optional[ListDatasourcesRequestOrderBy] = None,
        project_id: Optional[str] = None,
        types: Optional[List[DatasourceType]] = None,
        is_managed_by_scaleway: Optional[bool] = None,
    ) -> ListDatasourcesResponse:
        """
        Get a list of data sources for the specified Project ID.
        :param page: Page number.
        :param page_size: Page size.
        :param order_by: How the response is ordered.
        :param project_id: ID of the Project.
        :param types: Filter by datasource types.
        :param is_managed_by_scaleway: Filter by managed datasources.
        :return: :class:`ListDatasourcesResponse <ListDatasourcesResponse>`

        Usage:
        ::

            result = api.list_datasources()
        """

        res = self._request(
            "GET",
            "/cockpit/v1beta1/datasources",
            params={
                "is_managed_by_scaleway": is_managed_by_scaleway,
                "order_by": order_by,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
                "types": types,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListDatasourcesResponse(res.json())

    def list_datasources_all(
        self,
        *,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        order_by: Optional[ListDatasourcesRequestOrderBy] = None,
        project_id: Optional[str] = None,
        types: Optional[List[DatasourceType]] = None,
        is_managed_by_scaleway: Optional[bool] = None,
    ) -> List[Datasource]:
        """
        Get a list of data sources for the specified Project ID.
        :param page: Page number.
        :param page_size: Page size.
        :param order_by: How the response is ordered.
        :param project_id: ID of the Project.
        :param types: Filter by datasource types.
        :param is_managed_by_scaleway: Filter by managed datasources.
        :return: :class:`List[Datasource] <List[Datasource]>`

        Usage:
        ::

            result = api.list_datasources_all()
        """

        return fetch_all_pages(
            type=ListDatasourcesResponse,
            key="datasources",
            fetcher=self.list_datasources,
            args={
                "page": page,
                "page_size": page_size,
                "order_by": order_by,
                "project_id": project_id,
                "types": types,
                "is_managed_by_scaleway": is_managed_by_scaleway,
            },
        )

    def create_token(
        self,
        *,
        project_id: Optional[str] = None,
        name: Optional[str] = None,
        scopes: Optional[TokenScopes] = None,
    ) -> Token:
        """
        Create a token in a given Project specified by the Project ID.
        :param project_id: ID of the Project.
        :param name: Name of the token.
        :param scopes: Token's permissions.
        :return: :class:`Token <Token>`

        Usage:
        ::

            result = api.create_token()
        """

        res = self._request(
            "POST",
            "/cockpit/v1beta1/tokens",
            body=marshal_CreateTokenRequest(
                CreateTokenRequest(
                    project_id=project_id,
                    name=name or random_name(prefix="token"),
                    scopes=scopes,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_Token(res.json())

    def list_tokens(
        self,
        *,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        order_by: Optional[ListTokensRequestOrderBy] = None,
        project_id: Optional[str] = None,
    ) -> ListTokensResponse:
        """
        Get a list of tokens in a given Project specified by the Project ID.
        :param page: Page number.
        :param page_size: Page size.
        :param order_by: How the response is ordered.
        :param project_id: ID of the Project.
        :return: :class:`ListTokensResponse <ListTokensResponse>`

        Usage:
        ::

            result = api.list_tokens()
        """

        res = self._request(
            "GET",
            "/cockpit/v1beta1/tokens",
            params={
                "order_by": order_by,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListTokensResponse(res.json())

    def list_tokens_all(
        self,
        *,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        order_by: Optional[ListTokensRequestOrderBy] = None,
        project_id: Optional[str] = None,
    ) -> List[Token]:
        """
        Get a list of tokens in a given Project specified by the Project ID.
        :param page: Page number.
        :param page_size: Page size.
        :param order_by: How the response is ordered.
        :param project_id: ID of the Project.
        :return: :class:`List[Token] <List[Token]>`

        Usage:
        ::

            result = api.list_tokens_all()
        """

        return fetch_all_pages(
            type=ListTokensResponse,
            key="tokens",
            fetcher=self.list_tokens,
            args={
                "page": page,
                "page_size": page_size,
                "order_by": order_by,
                "project_id": project_id,
            },
        )

    def get_token(
        self,
        *,
        token_id: str,
    ) -> Token:
        """
        Retrieve a given token specified by the token ID.
        :param token_id: ID of the token.
        :return: :class:`Token <Token>`

        Usage:
        ::

            result = api.get_token(
                token_id="example",
            )
        """

        param_token_id = validate_path_param("token_id", token_id)

        res = self._request(
            "GET",
            f"/cockpit/v1beta1/tokens/{param_token_id}",
        )

        self._throw_on_error(res)
        return unmarshal_Token(res.json())

    def delete_token(
        self,
        *,
        token_id: str,
    ) -> None:
        """
        Delete a given token specified by the token ID.
        :param token_id: ID of the token.

        Usage:
        ::

            result = api.delete_token(
                token_id="example",
            )
        """

        param_token_id = validate_path_param("token_id", token_id)

        res = self._request(
            "DELETE",
            f"/cockpit/v1beta1/tokens/{param_token_id}",
        )

        self._throw_on_error(res)

    def create_contact_point(
        self,
        *,
        project_id: Optional[str] = None,
        contact_point: Optional[ContactPoint] = None,
    ) -> ContactPoint:
        """
        Create a contact point associated with the default receiver, to receive alerts.
        :param project_id: ID of the Project in which to create the contact point.
        :param contact_point: Contact point to create.
        :return: :class:`ContactPoint <ContactPoint>`

        Usage:
        ::

            result = api.create_contact_point()
        """

        res = self._request(
            "POST",
            "/cockpit/v1beta1/contact-points",
            body=marshal_CreateContactPointRequest(
                CreateContactPointRequest(
                    project_id=project_id,
                    contact_point=contact_point,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_ContactPoint(res.json())

    def list_contact_points(
        self,
        *,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        project_id: Optional[str] = None,
    ) -> ListContactPointsResponse:
        """
        Get a list of contact points created for a given Cockpit, specified by the ID of the Project the Cockpit belongs to.
        :param page: Page number.
        :param page_size: Page size.
        :param project_id: ID of the Project from which to list the contact points.
        :return: :class:`ListContactPointsResponse <ListContactPointsResponse>`

        Usage:
        ::

            result = api.list_contact_points()
        """

        res = self._request(
            "GET",
            "/cockpit/v1beta1/contact-points",
            params={
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListContactPointsResponse(res.json())

    def list_contact_points_all(
        self,
        *,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        project_id: Optional[str] = None,
    ) -> List[ContactPoint]:
        """
        Get a list of contact points created for a given Cockpit, specified by the ID of the Project the Cockpit belongs to.
        :param page: Page number.
        :param page_size: Page size.
        :param project_id: ID of the Project from which to list the contact points.
        :return: :class:`List[ContactPoint] <List[ContactPoint]>`

        Usage:
        ::

            result = api.list_contact_points_all()
        """

        return fetch_all_pages(
            type=ListContactPointsResponse,
            key="contact_points",
            fetcher=self.list_contact_points,
            args={
                "page": page,
                "page_size": page_size,
                "project_id": project_id,
            },
        )

    def delete_contact_point(
        self,
        *,
        project_id: Optional[str] = None,
        contact_point: Optional[ContactPoint] = None,
    ) -> None:
        """
        Delete a contact point associated with the default receiver.
        :param project_id: ID of the Project.
        :param contact_point: Contact point to delete.

        Usage:
        ::

            result = api.delete_contact_point()
        """

        res = self._request(
            "POST",
            "/cockpit/v1beta1/delete-contact-point",
            body=marshal_DeleteContactPointRequest(
                DeleteContactPointRequest(
                    project_id=project_id,
                    contact_point=contact_point,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)

    def enable_managed_alerts(
        self,
        *,
        project_id: Optional[str] = None,
    ) -> None:
        """
        Enable the sending of managed alerts for a given Cockpit, specified by the ID of the Project the Cockpit belongs to.
        :param project_id: ID of the Project.

        Usage:
        ::

            result = api.enable_managed_alerts()
        """

        res = self._request(
            "POST",
            "/cockpit/v1beta1/enable-managed-alerts",
            body=marshal_EnableManagedAlertsRequest(
                EnableManagedAlertsRequest(
                    project_id=project_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)

    def disable_managed_alerts(
        self,
        *,
        project_id: Optional[str] = None,
    ) -> None:
        """
        Disable the sending of managed alerts for a given Cockpit, specified by the ID of the Project the Cockpit belongs to.
        :param project_id: ID of the Project.

        Usage:
        ::

            result = api.disable_managed_alerts()
        """

        res = self._request(
            "POST",
            "/cockpit/v1beta1/disable-managed-alerts",
            body=marshal_DisableManagedAlertsRequest(
                DisableManagedAlertsRequest(
                    project_id=project_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)

    def trigger_test_alert(
        self,
        *,
        project_id: Optional[str] = None,
    ) -> None:
        """
        Send a test alert to make sure your contact points get notified when an actual alert is triggered.
        :param project_id:

        Usage:
        ::

            result = api.trigger_test_alert()
        """

        res = self._request(
            "POST",
            "/cockpit/v1beta1/trigger-test-alert",
            body=marshal_TriggerTestAlertRequest(
                TriggerTestAlertRequest(
                    project_id=project_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)

    def create_grafana_user(
        self,
        *,
        login: str,
        project_id: Optional[str] = None,
        role: Optional[GrafanaUserRole] = None,
    ) -> GrafanaUser:
        """
        Create a Grafana user for your Cockpit's Grafana. Make sure you save the automatically-generated password and the Grafana user ID.
        :param login: Username of the Grafana user.
        :param project_id: ID of the Project.
        :param role: Role assigned to the Grafana user.
        :return: :class:`GrafanaUser <GrafanaUser>`

        Usage:
        ::

            result = api.create_grafana_user(
                login="example",
            )
        """

        res = self._request(
            "POST",
            "/cockpit/v1beta1/grafana-users",
            body=marshal_CreateGrafanaUserRequest(
                CreateGrafanaUserRequest(
                    login=login,
                    project_id=project_id,
                    role=role,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_GrafanaUser(res.json())

    def list_grafana_users(
        self,
        *,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        order_by: Optional[ListGrafanaUsersRequestOrderBy] = None,
        project_id: Optional[str] = None,
    ) -> ListGrafanaUsersResponse:
        """
        Get a list of all Grafana users created in your Cockpit's Grafana.
        :param page: Page number.
        :param page_size: Page size.
        :param order_by:
        :param project_id: ID of the Project.
        :return: :class:`ListGrafanaUsersResponse <ListGrafanaUsersResponse>`

        Usage:
        ::

            result = api.list_grafana_users()
        """

        res = self._request(
            "GET",
            "/cockpit/v1beta1/grafana-users",
            params={
                "order_by": order_by,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListGrafanaUsersResponse(res.json())

    def list_grafana_users_all(
        self,
        *,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        order_by: Optional[ListGrafanaUsersRequestOrderBy] = None,
        project_id: Optional[str] = None,
    ) -> List[GrafanaUser]:
        """
        Get a list of all Grafana users created in your Cockpit's Grafana.
        :param page: Page number.
        :param page_size: Page size.
        :param order_by:
        :param project_id: ID of the Project.
        :return: :class:`List[GrafanaUser] <List[GrafanaUser]>`

        Usage:
        ::

            result = api.list_grafana_users_all()
        """

        return fetch_all_pages(
            type=ListGrafanaUsersResponse,
            key="grafana_users",
            fetcher=self.list_grafana_users,
            args={
                "page": page,
                "page_size": page_size,
                "order_by": order_by,
                "project_id": project_id,
            },
        )

    def delete_grafana_user(
        self,
        *,
        project_id: Optional[str] = None,
        grafana_user_id: int,
    ) -> None:
        """
        Delete a Grafana user from your Cockpit's Grafana, specified by the ID of the Project the Cockpit belongs to, and the ID of the Grafana user.
        :param project_id: ID of the Project.
        :param grafana_user_id: ID of the Grafana user.

        Usage:
        ::

            result = api.delete_grafana_user(
                grafana_user_id=1,
            )
        """

        param_grafana_user_id = validate_path_param("grafana_user_id", grafana_user_id)

        res = self._request(
            "POST",
            f"/cockpit/v1beta1/grafana-users/{param_grafana_user_id}/delete",
            body=marshal_DeleteGrafanaUserRequest(
                DeleteGrafanaUserRequest(
                    project_id=project_id,
                    grafana_user_id=grafana_user_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)

    def reset_grafana_user_password(
        self,
        *,
        project_id: Optional[str] = None,
        grafana_user_id: int,
    ) -> GrafanaUser:
        """
        Reset the password of a Grafana user, specified by the ID of the Project the Cockpit belongs to, and the ID of the Grafana user.
        :param project_id: ID of the Project.
        :param grafana_user_id: ID of the Grafana user.
        :return: :class:`GrafanaUser <GrafanaUser>`

        Usage:
        ::

            result = api.reset_grafana_user_password(
                grafana_user_id=1,
            )
        """

        param_grafana_user_id = validate_path_param("grafana_user_id", grafana_user_id)

        res = self._request(
            "POST",
            f"/cockpit/v1beta1/grafana-users/{param_grafana_user_id}/reset-password",
            body=marshal_ResetGrafanaUserPasswordRequest(
                ResetGrafanaUserPasswordRequest(
                    project_id=project_id,
                    grafana_user_id=grafana_user_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_GrafanaUser(res.json())

    def list_plans(
        self,
        *,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        order_by: Optional[ListPlansRequestOrderBy] = None,
    ) -> ListPlansResponse:
        """
        Get a list of all pricing plans available.
        :param page: Page number.
        :param page_size: Page size.
        :param order_by:
        :return: :class:`ListPlansResponse <ListPlansResponse>`

        Usage:
        ::

            result = api.list_plans()
        """

        res = self._request(
            "GET",
            "/cockpit/v1beta1/plans",
            params={
                "order_by": order_by,
                "page": page,
                "page_size": page_size or self.client.default_page_size,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListPlansResponse(res.json())

    def list_plans_all(
        self,
        *,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        order_by: Optional[ListPlansRequestOrderBy] = None,
    ) -> List[Plan]:
        """
        Get a list of all pricing plans available.
        :param page: Page number.
        :param page_size: Page size.
        :param order_by:
        :return: :class:`List[Plan] <List[Plan]>`

        Usage:
        ::

            result = api.list_plans_all()
        """

        return fetch_all_pages(
            type=ListPlansResponse,
            key="plans",
            fetcher=self.list_plans,
            args={
                "page": page,
                "page_size": page_size,
                "order_by": order_by,
            },
        )

    def select_plan(
        self,
        *,
        plan_id: str,
        project_id: Optional[str] = None,
    ) -> SelectPlanResponse:
        """
        Select your chosen pricing plan for your Cockpit, specifying the Cockpit's Project ID and the pricing plan's ID in the request.
        :param plan_id: ID of the pricing plan.
        :param project_id: ID of the Project.
        :return: :class:`SelectPlanResponse <SelectPlanResponse>`

        Usage:
        ::

            result = api.select_plan(
                plan_id="example",
            )
        """

        res = self._request(
            "POST",
            "/cockpit/v1beta1/select-plan",
            body=marshal_SelectPlanRequest(
                SelectPlanRequest(
                    plan_id=plan_id,
                    project_id=project_id,
                ),
                self.client,
            ),
        )

        self._throw_on_error(res)
        return unmarshal_SelectPlanResponse(res.json())

    def list_grafana_product_dashboards(
        self,
        *,
        project_id: Optional[str] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        tags: Optional[List[str]] = None,
    ) -> ListGrafanaProductDashboardsResponse:
        """
        List product dashboards.
        Get a list of available product dashboards.
        :param project_id: ID of the Project.
        :param page: Page number.
        :param page_size: Page size.
        :param tags: Tags to filter the dashboards.
        :return: :class:`ListGrafanaProductDashboardsResponse <ListGrafanaProductDashboardsResponse>`

        Usage:
        ::

            result = api.list_grafana_product_dashboards()
        """

        res = self._request(
            "GET",
            "/cockpit/v1beta1/grafana-product-dashboards",
            params={
                "page": page,
                "page_size": page_size or self.client.default_page_size,
                "project_id": project_id or self.client.default_project_id,
                "tags": tags,
            },
        )

        self._throw_on_error(res)
        return unmarshal_ListGrafanaProductDashboardsResponse(res.json())

    def list_grafana_product_dashboards_all(
        self,
        *,
        project_id: Optional[str] = None,
        page: Optional[int] = None,
        page_size: Optional[int] = None,
        tags: Optional[List[str]] = None,
    ) -> List[GrafanaProductDashboard]:
        """
        List product dashboards.
        Get a list of available product dashboards.
        :param project_id: ID of the Project.
        :param page: Page number.
        :param page_size: Page size.
        :param tags: Tags to filter the dashboards.
        :return: :class:`List[GrafanaProductDashboard] <List[GrafanaProductDashboard]>`

        Usage:
        ::

            result = api.list_grafana_product_dashboards_all()
        """

        return fetch_all_pages(
            type=ListGrafanaProductDashboardsResponse,
            key="dashboards",
            fetcher=self.list_grafana_product_dashboards,
            args={
                "project_id": project_id,
                "page": page,
                "page_size": page_size,
                "tags": tags,
            },
        )

    def get_grafana_product_dashboard(
        self,
        *,
        project_id: Optional[str] = None,
        dashboard_name: str,
    ) -> GrafanaProductDashboard:
        """
        Get a product dashboard.
        Get a product dashboard specified by the dashboard ID.
        :param project_id: ID of the Project.
        :param dashboard_name: Name of the dashboard.
        :return: :class:`GrafanaProductDashboard <GrafanaProductDashboard>`

        Usage:
        ::

            result = api.get_grafana_product_dashboard(
                dashboard_name="example",
            )
        """

        param_dashboard_name = validate_path_param("dashboard_name", dashboard_name)

        res = self._request(
            "GET",
            f"/cockpit/v1beta1/grafana-product-dashboards/{param_dashboard_name}",
            params={
                "project_id": project_id or self.client.default_project_id,
            },
        )

        self._throw_on_error(res)
        return unmarshal_GrafanaProductDashboard(res.json())
